@@ -1,5 +1,5 @@
+use fancy_regex::{Captures, Regex};
 use helper::coordinate::*;
-use onig::*;
 
 pub fn adjustment_insert_formula_coordinate(
     formula: &str,
@@ -11,10 +11,9 @@ pub fn adjustment_insert_formula_coordinate(
     self_worksheet_name: &str,
 ) -> String {
     let re = Regex::new(r#"[^\(]*!*[A-Z]+[0-9]+\:[A-Z]+[0-9]+"#).unwrap();
-
-    re.replace_all(formula, |caps: &Captures| {
-        let caps_string: String = caps.at(0).unwrap().parse().unwrap();
-        let split_str: Vec<&str> = caps_string.split('!').collect();
+    let result = re.replace_all(formula, |caps: &Captures| {
+        let caps_string = (&caps.get(0).unwrap()).as_str().to_string();
+        let split_str: Vec<&str> = caps_string.split("!").collect();
         let with_wksheet: bool;
         let wksheet: String;
         let range: String;
@@ -51,7 +50,8 @@ pub fn adjustment_insert_formula_coordinate(
             result = format!("{}!{}", wksheet, result);
         }
         result
-    })
+    });
+    result.to_string()
 }
 
 pub fn adjustment_remove_formula_coordinate(
@@ -64,10 +64,9 @@ pub fn adjustment_remove_formula_coordinate(
     self_worksheet_name: &str,
 ) -> String {
     let re = Regex::new(r#"[^\(]*!*[A-Z]+[0-9]+\:[A-Z]+[0-9]+"#).unwrap();
-
-    re.replace_all(formula, |caps: &Captures| {
-        let caps_string: String = caps.at(0).unwrap().parse().unwrap();
-        let split_str: Vec<&str> = caps_string.split('!').collect();
+    let result = re.replace_all(formula, |caps: &Captures| {
+        let caps_string = (&caps.get(0).unwrap()).as_str().to_string();
+        let split_str: Vec<&str> = caps_string.split("!").collect();
         let with_wksheet: bool;
         let wksheet: String;
         let range: String;
@@ -104,5 +103,6 @@ pub fn adjustment_remove_formula_coordinate(
             result = format!("{}!{}", wksheet, result);
         }
         result
-    })
+    });
+    result.into()
 }
