@@ -9,8 +9,7 @@
 //! let mut book = reader::xlsx::read(path).unwrap();
 //! // or
 //! // lazy reader
-//! //  Delays the loading of the worksheet until it is needed.
-//! //  When loading a file with a large amount of data, response improvement can be expected.
+//! //  Delays the loading of the worksheet until it is needed.//! //  When loading a file with a large amount of data, response improvement can be expected.
 //! let path = std::path::Path::new("./tests/test_files/aaa.xlsx");
 //! let mut book = reader::xlsx::lazy_read(path).unwrap();
 //! // or
@@ -30,7 +29,7 @@
 //! use umya_spreadsheet::*;
 //! let mut book = new_file();
 //!
-//! let mut clone_sheet = book.get_sheet(0).unwrap().clone();
+//! let mut clone_sheet = book.get_sheet(&0).unwrap().clone();
 //! clone_sheet.set_name("New Sheet");
 //! let _ = book.add_sheet(clone_sheet);
 //! ```
@@ -45,9 +44,9 @@
 //! book.get_sheet_by_name_mut("Sheet2").unwrap().get_cell_mut("B2").set_value_from_i32(1);
 //! book.get_sheet_by_name_mut("Sheet2").unwrap().get_cell_mut("C3").set_value_from_bool(true);
 //! // or
-//! book.get_sheet_mut(1).get_cell_by_column_and_row_mut(1, 1).set_value("TEST1");
-//! book.get_sheet_mut(1).get_cell_by_column_and_row_mut(2, 2).set_value_from_i32(1);
-//! book.get_sheet_mut(1).get_cell_by_column_and_row_mut(3, 3).set_value_from_bool(true);
+//! book.get_sheet_mut(&1).unwrap().get_cell_by_column_and_row_mut(&1, &1).set_value("TEST1");
+//! book.get_sheet_mut(&1).unwrap().get_cell_by_column_and_row_mut(&2, &2).set_value_from_i32(1);
+//! book.get_sheet_mut(&1).unwrap().get_cell_by_column_and_row_mut(&3, &3).set_value_from_bool(true);
 //! ```
 //! ### Read value
 //! ```rust
@@ -59,9 +58,9 @@
 //! // read value
 //! let a1_value = book.get_sheet_by_name("Sheet2").unwrap().get_value("A1");
 //! // or
-//! let a1_value = book.get_sheet(1).unwrap().get_value_by_column_and_row(1, 1);
+//! let a1_value = book.get_sheet(&1).unwrap().get_value_by_column_and_row(&1, &1);
 //! // or formatted value
-//! let a1_value = book.get_sheet(1).unwrap().get_formatted_value("A1");
+//! let a1_value = book.get_sheet(&1).unwrap().get_formatted_value("A1");
 //! assert_eq!("TEST1", a1_value);  // TEST1
 //! ```
 //! ### Change style
@@ -78,8 +77,8 @@
 //! .get_bottom_mut()
 //! .set_border_style(Border::BORDER_MEDIUM);
 //! // or
-//! book.get_sheet_mut(1)
-//! .get_style_by_column_and_row_mut(1, 1)
+//! book.get_sheet_mut(&1).unwrap()
+//! .get_style_by_column_and_row_mut(&1, &1)
 //! .get_borders_mut()
 //! .get_bottom_mut()
 //! .set_border_style(Border::BORDER_MEDIUM);
@@ -91,20 +90,20 @@
 //! let mut book = new_file();
 //!
 //! // insert rows
-//! book.insert_new_row("Sheet1", 2, 3);
+//! book.insert_new_row("Sheet1", &2, &3);
 //!
 //! // insert columns
-//! book.insert_new_column("Sheet1", "B", 3);
+//! book.insert_new_column("Sheet1", "B", &3);
 //! // or
-//! book.insert_new_column_by_index("Sheet1", 2, 3);
+//! book.insert_new_column_by_index("Sheet1", &2, &3);
 //!
 //! // remove rows
-//! book.remove_row("Sheet1", 6, 2);
+//! book.remove_row("Sheet1", &6, &2);
 //!
 //! // remove columns
-//! book.remove_column("Sheet1", "F", 2);
+//! book.remove_column("Sheet1", "F", &2);
 //! // or
-//! book.remove_column_by_index("Sheet1", 6, 2);
+//! book.remove_column_by_index("Sheet1", &6, &2);
 //! ```
 //! ### Writer
 //! ```rust
@@ -120,12 +119,12 @@
 extern crate chrono;
 extern crate image;
 extern crate md5;
-extern crate onig;
+// extern crate onig;
+extern crate fancy_regex;
+extern crate hashbrown;
 extern crate quick_xml;
-extern crate regex;
 extern crate thousands;
 extern crate zip;
-extern crate hashbrown;
 
 #[macro_use]
 extern crate lazy_static;
@@ -147,7 +146,7 @@ pub use self::structs::*;
 /// ```
 pub fn new_file() -> structs::Spreadsheet {
     let mut spreadsheet = structs::Spreadsheet::default();
-    spreadsheet.set_theme(Theme::get_defalut_value());
+    spreadsheet.set_theme(structs::drawing::Theme::get_defalut_value());
     spreadsheet.set_stylesheet_defalut_value();
     let worksheet = spreadsheet.new_sheet("Sheet1").unwrap();
     worksheet.set_active_cell("A1");
@@ -168,7 +167,7 @@ pub fn new_file() -> structs::Spreadsheet {
 /// ```
 pub fn new_file_empty_worksheet() -> structs::Spreadsheet {
     let mut spreadsheet = structs::Spreadsheet::default();
-    spreadsheet.set_theme(Theme::get_defalut_value());
+    spreadsheet.set_theme(structs::drawing::Theme::get_defalut_value());
     spreadsheet.set_stylesheet_defalut_value();
     spreadsheet
 }
