@@ -6,11 +6,11 @@ use std::sync::Arc;
 use std::sync::RwLock;
 
 use super::driver;
+use structs::drawing::Theme;
 use structs::raw::RawWorksheet;
 use structs::SharedStringTable;
 use structs::Spreadsheet;
 use structs::Stylesheet;
-use structs::Theme;
 use structs::Worksheet;
 
 pub(crate) mod chart;
@@ -79,6 +79,7 @@ pub fn read_reader<R: io::Read + io::Seek>(
     content_types::read(&mut arv, &mut book).unwrap();
     let workbook_rel = workbook_rels::read(&mut arv, &mut book).unwrap();
 
+    book.set_theme(Theme::get_defalut_value());
     for (_, type_value, rel_target) in &workbook_rel {
         match type_value.as_str() {
             "http://schemas.openxmlformats.org/officeDocument/2006/relationships/theme" => {
@@ -88,7 +89,6 @@ pub fn read_reader<R: io::Read + io::Seek>(
             _ => {}
         }
     }
-    let _theme = book.get_theme().clone();
 
     shared_strings::read(&mut arv, &mut book).unwrap();
     styles::read(&mut arv, &mut book).unwrap();
@@ -121,7 +121,7 @@ pub fn read_reader<R: io::Read + io::Seek>(
 /// let path = std::path::Path::new("./tests/test_files/aaa.xlsx");
 /// let mut book = umya_spreadsheet::reader::xlsx::read(path).unwrap();
 /// ```
-pub fn read(path: &Path) -> Result<Spreadsheet, XlsxError> {
+pub fn read<P: AsRef<Path>>(path: P) -> Result<Spreadsheet, XlsxError> {
     let file = File::open(path)?;
     read_reader(file, true)
 }
