@@ -11,7 +11,15 @@ pub(crate) fn read<R: io::Read + io::Seek>(
     arv: &mut zip::ZipArchive<R>,
     spreadsheet: &mut Spreadsheet,
 ) -> result::Result<(), XlsxError> {
-    let r = io::BufReader::new(arv.by_name(FILE_PATH)?);
+    let r = io::BufReader::new(match arv.by_name(FILE_PATH) {
+        Ok(v) => v,
+        Err(zip::result::ZipError::FileNotFound) => {
+            return Ok(());
+        }
+        Err(e) => {
+            return Err(e.into());
+        }
+    });
     let mut reader = Reader::from_reader(r);
     reader.trim_text(true);
     let mut buf = Vec::new();
