@@ -22,9 +22,6 @@ pub use self::cells::*;
 mod hyperlink;
 pub use self::hyperlink::*;
 
-mod shadow;
-pub(crate) use self::shadow::*;
-
 mod color;
 pub use self::color::*;
 
@@ -49,9 +46,6 @@ pub use self::column::*;
 mod security;
 pub use self::security::*;
 
-mod calculation;
-pub(crate) use self::calculation::*;
-
 mod style;
 pub use self::style::*;
 
@@ -82,9 +76,6 @@ pub use self::rich_text::*;
 mod text_element;
 pub use self::text_element::*;
 
-mod theme;
-pub use self::theme::*;
-
 mod cell_style;
 pub use self::cell_style::*;
 
@@ -280,9 +271,6 @@ pub use self::column_reference::*;
 mod columns;
 pub(crate) use self::columns::*;
 
-mod column_sort;
-pub use self::column_sort::*;
-
 mod sequence_of_references;
 pub use self::sequence_of_references::*;
 
@@ -378,3 +366,6 @@ pub use self::csv_writer_option::*;
 
 mod csv_encode_values;
 pub use self::csv_encode_values::*;
+
+mod cell_raw_value;
+pub use self::cell_raw_value::*;
