@@ -1,13 +1,12 @@
 #[derive(Clone, Default, Debug, Eq, Ord, PartialEq, PartialOrd)]
 pub struct BooleanValue {
     value: Option<bool>,
-    value_default: bool,
 }
 impl BooleanValue {
     pub(crate) fn get_value(&self) -> &bool {
         match &self.value {
             Some(v) => v,
-            None => &self.value_default,
+            None => &false,
         }
     }
 
@@ -19,13 +18,18 @@ impl BooleanValue {
         }
     }
 
-    pub(crate) fn set_value(&mut self, value: bool) -> &mut BooleanValue {
+    pub(crate) fn set_value(&mut self, value: bool) -> &mut Self {
         self.value = Some(value);
         self
     }
 
-    pub(crate) fn set_value_string<S: Into<String>>(&mut self, value: S) -> &mut BooleanValue {
-        self.set_value(value.into() != "0")
+    pub(crate) fn set_value_string<S: Into<String>>(&mut self, value: S) -> &mut Self {
+        let v = match value.into().as_str() {
+            "true" => true,
+            "1" => true,
+            _ => false,
+        };
+        self.set_value(v)
     }
 
     pub(crate) fn has_value(&self) -> bool {
