@@ -80,15 +80,22 @@ impl Break {
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
         // brk
         let mut attributes: Vec<(&str, &str)> = Vec::new();
-        attributes.push(("id", self.id.get_value_string()));
+        let id = self.id.get_value_string();
+        attributes.push(("id", &id));
+
+        let max = self.max.get_value_string();
         if self.max.has_value() {
-            attributes.push(("max", self.max.get_value_string()));
+            attributes.push(("max", &max));
         }
+
+        let min = self.min.get_value_string();
         if self.min.has_value() {
-            attributes.push(("min", self.min.get_value_string()));
+            attributes.push(("min", &min));
         }
+
+        let manual_page_break = self.manual_page_break.get_value_string();
         if self.manual_page_break.has_value() {
-            attributes.push(("man", self.manual_page_break.get_value_string()));
+            attributes.push(("man", &manual_page_break));
         }
         write_start_tag(writer, "brk", attributes, true);
     }
