@@ -3,8 +3,10 @@ use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
 use quick_xml::Writer;
 use reader::driver::*;
+use std::borrow::Cow;
 use std::io::Cursor;
 use std::sync::{Arc, RwLock};
+use structs::CellRawValue;
 use structs::CellValue;
 use structs::Coordinate;
 use structs::Hyperlink;
@@ -24,16 +26,6 @@ pub struct Cell {
     hyperlink: Option<Hyperlink>,
 }
 impl Cell {
-    // Data types
-    pub const TYPE_STRING2: &'static str = "str";
-    pub const TYPE_STRING: &'static str = "s";
-    pub const TYPE_FORMULA: &'static str = "f";
-    pub const TYPE_NUMERIC: &'static str = "n";
-    pub const TYPE_BOOL: &'static str = "b";
-    pub const TYPE_NULL: &'static str = "null";
-    pub const TYPE_INLINE: &'static str = "inlineStr";
-    pub const TYPE_ERROR: &'static str = "e";
-
     pub fn get_cell_value(&self) -> &CellValue {
         &self.cell_value
     }
@@ -86,28 +78,12 @@ impl Cell {
         self
     }
 
-    pub fn get_value(&self) -> &str {
-        match &self.cell_value.value {
-            Some(v) => {
-                return v;
-            }
-            None => {}
-        }
-        match &self.cell_value.rich_text {
-            Some(v) => {
-                return v.get_text();
-            }
-            None => {}
-        }
-        ""
+    pub fn get_value(&self) -> Cow<'static, str> {
+        self.cell_value.get_value()
     }
 
-    pub(crate) fn _get_value_crate(&self) -> &Option<String> {
-        &self.cell_value.value
-    }
-
-    pub fn get_rich_text(&self) -> &Option<RichText> {
-        &self.cell_value.rich_text
+    pub fn get_value_lazy(&mut self) -> Cow<'static, str> {
+        self.cell_value.get_value_lazy()
     }
 
     pub fn set_value<S: Into<String>>(&mut self, value: S) -> &mut Self {
@@ -115,6 +91,11 @@ impl Cell {
         self
     }
 
+    pub fn set_value_lazy<S: Into<String>>(&mut self, value: S) -> &mut Self {
+        self.cell_value.set_value_lazy(value);
+        self
+    }
+
     pub fn set_value_from_string<S: Into<String>>(&mut self, value: S) -> &mut Self {
         self.cell_value.set_value_from_string(value);
         self
@@ -220,13 +201,16 @@ impl Cell {
         self
     }
 
-    pub fn get_data_type(&self) -> &str {
-        &self.cell_value.data_type
+    pub fn get_data_type(&self) -> &CellRawValue {
+        self.cell_value.get_data_type()
     }
 
-    pub fn set_data_type<S: Into<String>>(&mut self, value: S) -> &mut Self {
-        self.cell_value.set_data_type(value);
-        self
+    pub fn get_raw_value(&self) -> &CellRawValue {
+        self.cell_value.get_raw_value()
+    }
+
+    pub(crate) fn get_data_type_crate(&self) -> &str {
+        self.cell_value.get_data_type_crate()
     }
 
     pub fn is_formula(&self) -> bool {
@@ -240,6 +224,7 @@ impl Cell {
     pub(crate) fn get_formula_attributes(&self) -> Vec<(&str, &str)> {
         self.cell_value.get_formula_attributes()
     }
+
     pub(crate) fn set_formula_attributes(&mut self, attributes: Vec<(String, String)>) {
         self.cell_value.set_formula_attributes(attributes);
     }
@@ -285,8 +270,8 @@ impl Cell {
 
         // convert value
         let result = match self.get_style().get_number_format() {
-            Some(nmuber_format) => to_formatted_string(value, nmuber_format.get_format_code()),
-            None => to_formatted_string(value, NumberingFormat::FORMAT_GENERAL),
+            Some(nmuber_format) => to_formatted_string(&value, &nmuber_format.get_format_code()),
+            None => to_formatted_string(&value, &NumberingFormat::FORMAT_GENERAL),
         };
         result
     }
@@ -370,8 +355,8 @@ impl Cell {
                         } else if type_value == "b" {
                             let prm = &string_value == "1";
                             let _ = self.set_value_from_bool(prm);
-                        } else if type_value.is_empty() || type_value == "n" {
-                            let _ = self.set_value(&string_value);
+                        } else if type_value == "" || type_value == "n" {
+                            let _ = self.set_value(string_value.clone());
                         };
                     }
                     b"c" => return,
@@ -401,8 +386,8 @@ impl Cell {
         let mut attributes: Vec<(&str, &str)> = Vec::new();
         let coordinate = self.coordinate.get_coordinate();
         attributes.push(("r", &coordinate));
-        if self.get_data_type() == "s" || self.get_data_type() == "b" {
-            attributes.push(("t", self.get_data_type()));
+        if self.get_data_type_crate() == "s" || self.get_data_type_crate() == "b" {
+            attributes.push(("t", self.get_data_type_crate()));
         }
         let xf_index_str: String;
         let xf_index = stylesheet.set_style(self.get_style());
@@ -425,7 +410,9 @@ impl Cell {
 
             // v
             write_start_tag(writer, "v", vec![], false);
-            match self.get_data_type() {
+
+            //todo use typed value
+            match self.get_data_type_crate() {
                 "s" => {
                     let val_index = shared_string_table
                         .write()
