@@ -136,7 +136,7 @@ impl CellFormat {
         self.apply_alignment.has_value()
     }
 
-    pub(crate) fn get_apply_protection(&self) -> &bool {
+    pub(crate) fn _get_apply_protection(&self) -> &bool {
         self.apply_protection.get_value()
     }
 
@@ -158,7 +158,7 @@ impl CellFormat {
         self
     }
 
-    pub(crate) fn get_hash_code(&self) -> String {
+    pub(crate) fn _get_hash_code(&self) -> String {
         format!(
             "{:x}",
             md5::Md5::digest(format!(
@@ -173,7 +173,7 @@ impl CellFormat {
                 &self.get_apply_border(),
                 &self.get_apply_font(),
                 &self.get_apply_alignment(),
-                &self.get_apply_protection(),
+                &self._get_apply_protection(),
                 match &self.get_alignment() {
                     Some(v) => {
                         v.get_hash_code()
@@ -291,12 +291,21 @@ impl CellFormat {
 
         // xf
         let mut attributes: Vec<(&str, &str)> = Vec::new();
-        attributes.push(("numFmtId", self.number_format_id.get_value_string()));
-        attributes.push(("fontId", self.font_id.get_value_string()));
-        attributes.push(("fillId", self.fill_id.get_value_string()));
-        attributes.push(("borderId", self.border_id.get_value_string()));
+        let number_format_id = self.number_format_id.get_value_string();
+        attributes.push(("numFmtId", &number_format_id));
+        let font_id = self.font_id.get_value_string();
+        attributes.push(("fontId", &font_id));
+        let fill_id = self.fill_id.get_value_string();
+        attributes.push(("fillId", &fill_id));
+        let border_id = self.border_id.get_value_string();
+        attributes.push(("borderId", &border_id));
+
+        let format_id = self.format_id.get_value_string();
         if is_cell_xfs {
-            attributes.push(("xfId", self.format_id.get_value_string()));
+            attributes.push(("xfId", &format_id));
+        }
+        if self.apply_font.has_value() {
+            attributes.push(("applyFont", self.apply_font.get_value_string()));
         }
         if self.apply_number_format.has_value() {
             attributes.push((
