@@ -1,84 +1,89 @@
 use super::RichText;
 use super::SharedStringItem;
+use super::Text;
 use helper::formula::*;
-use md5::Digest;
+use std::borrow::Cow;
+use structs::CellRawValue;
 
 #[derive(Clone, Default, Debug, PartialEq, PartialOrd)]
 pub struct CellValue {
-    pub(crate) data_type: String,
-    pub(crate) value: Option<String>,
-    pub(crate) rich_text: Option<RichText>,
+    pub(crate) raw_value: CellRawValue,
     pub(crate) formula: Option<String>,
     pub(crate) formula_attributes: Vec<(String, String)>,
 }
 impl CellValue {
-    // Data types
-    pub const TYPE_STRING2: &'static str = "str";
-    pub const TYPE_STRING: &'static str = "s";
-    pub const TYPE_FORMULA: &'static str = "f";
-    pub const TYPE_NUMERIC: &'static str = "n";
-    pub const TYPE_BOOL: &'static str = "b";
-    pub const TYPE_NULL: &'static str = "null";
-    pub const TYPE_INLINE: &'static str = "inlineStr";
-    pub const TYPE_ERROR: &'static str = "e";
+    pub fn get_data_type(&self) -> &CellRawValue {
+        &self.raw_value
+    }
+
+    pub fn get_raw_value(&self) -> &CellRawValue {
+        &self.raw_value
+    }
+
+    pub(crate) fn get_data_type_crate(&self) -> &str {
+        match &self.formula {
+            Some(_) => {
+                return "f";
+            }
+            None => {}
+        }
+        &self.raw_value.get_data_type()
+    }
 
     pub fn set_formula_attributes(&mut self, formula_attributes: Vec<(String, String)>) {
         self.formula_attributes = formula_attributes;
     }
+
     pub fn get_formula_attributes(&self) -> Vec<(&str, &str)> {
         self.formula_attributes
             .iter()
             .map(|(a, b)| (a.as_str(), b.as_str()))
             .collect()
     }
-    pub fn get_value(&self) -> &str {
-        match &self.value {
-            Some(v) => {
-                return v;
-            }
-            None => {}
-        }
-        match &self.rich_text {
-            Some(v) => {
-                return v.get_text();
-            }
-            None => {}
-        }
-        ""
+
+    pub fn get_value(&self) -> Cow<'static, str> {
+        self.raw_value.to_string().into()
     }
 
-    pub(crate) fn get_value_crate(&self) -> &Option<String> {
-        &self.value
+    pub fn get_value_lazy(&mut self) -> Cow<'static, str> {
+        match &self.raw_value {
+            CellRawValue::Lazy(v) => {
+                self.raw_value = Self::guess_typed_data(v);
+            }
+            _ => {}
+        }
+        self.formula = None;
+        self.raw_value.to_string().into()
     }
 
-    pub fn get_rich_text(&self) -> &Option<RichText> {
-        &self.rich_text
+    pub(crate) fn get_text(&self) -> Option<Text> {
+        self.raw_value.get_text()
+    }
+
+    pub(crate) fn get_rich_text(&self) -> Option<RichText> {
+        self.raw_value.get_rich_text()
     }
 
     pub fn set_value<S: Into<String>>(&mut self, value: S) -> &mut Self {
-        let value_org = value.into();
-        self.data_type = Self::data_type_for_value(&value_org).to_string();
-        self.value = Some(value_org);
-        self.rich_text = None;
+        self.raw_value = Self::guess_typed_data(&value.into());
+        self.formula = None;
+        self
+    }
+
+    pub fn set_value_lazy<S: Into<String>>(&mut self, value: S) -> &mut Self {
+        self.raw_value = CellRawValue::Lazy(value.into());
         self.formula = None;
         self
     }
 
     pub fn set_value_from_string<S: Into<String>>(&mut self, value: S) -> &mut Self {
-        self.data_type = Self::TYPE_STRING.to_string();
-        self.value = Some(value.into());
-        self.rich_text = None;
+        self.raw_value = CellRawValue::String(value.into());
         self.formula = None;
         self
     }
 
     pub fn set_value_from_bool(&mut self, value: bool) -> &mut Self {
-        self.data_type = Self::TYPE_BOOL.to_string();
-        self.value = Some(match value {
-            true => "TRUE".to_string(),
-            false => "FALSE".to_string(),
-        });
-        self.rich_text = None;
+        self.raw_value = CellRawValue::Bool(value);
         self.formula = None;
         self
     }
@@ -87,94 +92,14 @@ impl CellValue {
         self.set_value_from_bool(*value)
     }
 
-    pub fn set_value_from_u16(&mut self, value: u16) -> &mut Self {
-        self.data_type = Self::TYPE_NUMERIC.to_string();
-        self.value = Some(value.to_string());
-        self.rich_text = None;
+    pub fn set_value_from_numberic<V: Into<f64>>(&mut self, value: V) -> &mut Self {
+        self.raw_value = CellRawValue::Numeric(value.into());
         self.formula = None;
         self
     }
 
-    pub fn set_value_from_u16_ref(&mut self, value: &u16) -> &mut Self {
-        self.set_value_from_u16(*value)
-    }
-
-    pub fn set_value_from_u32(&mut self, value: u32) -> &mut Self {
-        self.data_type = Self::TYPE_NUMERIC.to_string();
-        self.value = Some(value.to_string());
-        self.rich_text = None;
-        self.formula = None;
-        self
-    }
-
-    pub fn set_value_from_u32_ref(&mut self, value: &u32) -> &mut Self {
-        self.set_value_from_u32(*value)
-    }
-
-    pub fn set_value_from_u64(&mut self, value: u64) -> &mut Self {
-        self.data_type = Self::TYPE_NUMERIC.to_string();
-        self.value = Some(value.to_string());
-        self.rich_text = None;
-        self.formula = None;
-        self
-    }
-
-    pub fn set_value_from_u64_ref(&mut self, value: &u64) -> &mut Self {
-        self.set_value_from_u64(*value)
-    }
-
-    pub fn set_value_from_i16(&mut self, value: i16) -> &mut Self {
-        self.data_type = Self::TYPE_NUMERIC.to_string();
-        self.value = Some(value.to_string());
-        self.rich_text = None;
-        self.formula = None;
-        self
-    }
-
-    pub fn set_value_from_i16_ref(&mut self, value: &i16) -> &mut Self {
-        self.set_value_from_i16(*value)
-    }
-
-    pub fn set_value_from_i32(&mut self, value: i32) -> &mut Self {
-        self.data_type = Self::TYPE_NUMERIC.to_string();
-        self.value = Some(value.to_string());
-        self.rich_text = None;
-        self.formula = None;
-        self
-    }
-
-    pub fn set_value_from_i32_ref(&mut self, value: &i32) -> &mut Self {
-        self.set_value_from_i32(*value)
-    }
-
-    pub fn set_value_from_i64(&mut self, value: i64) -> &mut Self {
-        self.data_type = Self::TYPE_NUMERIC.to_string();
-        self.value = Some(value.to_string());
-        self.rich_text = None;
-        self.formula = None;
-        self
-    }
-
-    pub fn set_value_from_i64_ref(&mut self, value: &i64) -> &mut Self {
-        self.set_value_from_i64(*value)
-    }
-
-    pub fn set_value_from_usize(&mut self, value: usize) -> &mut Self {
-        self.data_type = Self::TYPE_NUMERIC.to_string();
-        self.value = Some(value.to_string());
-        self.rich_text = None;
-        self.formula = None;
-        self
-    }
-
-    pub fn set_value_from_usize_ref(&mut self, value: &usize) -> &mut Self {
-        self.set_value_from_usize(*value)
-    }
-
     pub fn set_rich_text(&mut self, value: RichText) -> &mut Self {
-        self.data_type = Self::TYPE_STRING.to_string();
-        self.value = None;
-        self.rich_text = Some(value);
+        self.raw_value = CellRawValue::RichText(value);
         self.formula = None;
         self
     }
@@ -184,66 +109,29 @@ impl CellValue {
     }
 
     pub fn set_formula<S: Into<String>>(&mut self, value: S) -> &mut Self {
-        self.data_type = Self::TYPE_FORMULA.to_string();
-        self.value = None;
-        self.rich_text = None;
         self.formula = Some(value.into());
         self
     }
 
     pub(crate) fn set_shared_string_item(&mut self, value: SharedStringItem) -> &mut Self {
-        self.data_type = Self::TYPE_STRING.to_string();
         match value.get_text() {
             Some(v) => {
-                self.value = Some(v.get_value().to_string());
+                self.set_value_from_string(v.get_value());
+            }
+            None => {}
+        }
+        match value.get_rich_text() {
+            Some(v) => {
+                self.set_rich_text_ref(v);
             }
             None => {}
         }
-        self.rich_text = value.get_rich_text().clone();
         self.formula = None;
         self
     }
 
-    pub fn get_data_type(&self) -> &str {
-        &self.data_type
-    }
-
-    pub fn set_data_type<S: Into<String>>(&mut self, value: S) -> &mut Self {
-        let data_type = value.into();
-        match Self::check_data_type(self.get_value(), &data_type) {
-            Ok(_) => self.data_type = data_type,
-            Err(e) => panic!("Error at set_data_type {:?}", e),
-        }
-        self
-    }
-
-    pub(crate) fn check_data_type<S: Into<String>>(
-        value: S,
-        data_type: S,
-    ) -> Result<(), &'static str> {
-        match data_type.into().as_str() {
-            Self::TYPE_STRING2 => Ok(()),
-            Self::TYPE_STRING => Ok(()),
-            Self::TYPE_FORMULA => Ok(()),
-            Self::TYPE_NUMERIC => match &value.into().parse::<f64>() {
-                Ok(_) => Ok(()),
-                Err(_) => Err("Invalid numeric value for datatype Numeric"),
-            },
-            Self::TYPE_BOOL => {
-                let check_value = &value.into().to_uppercase();
-                if check_value == "TRUE" || check_value == "FALSE" {
-                    Ok(())
-                } else {
-                    Err("Invalid value for datatype Bool")
-                }
-            }
-            Self::TYPE_NULL => Ok(()),
-            _ => Err("Invalid datatype"),
-        }
-    }
-
     pub fn is_formula(&self) -> bool {
-        &self.data_type == Self::TYPE_FORMULA
+        self.formula.is_some()
     }
 
     pub fn get_formula(&self) -> &str {
@@ -256,56 +144,88 @@ impl CellValue {
         ""
     }
 
-    pub(crate) fn data_type_for_value(value: &str) -> &str {
-        let check_value = value.to_uppercase();
-
-        // Match the value against a few data types
-        if check_value == "NULL" {
-            return Self::TYPE_NULL;
-        }
-        match check_value.parse::<f64>() {
-            Ok(_) => return Self::TYPE_NUMERIC,
-            Err(_) => {}
-        }
-        if check_value == "TRUE" || check_value == "FALSE" {
-            return Self::TYPE_BOOL;
-        }
-        Self::TYPE_STRING
+    pub fn set_value_from_u16(&mut self, value: u16) -> &mut Self {
+        self.set_value_from_numberic(value)
     }
 
-    pub(crate) fn _get_hash_code_by_value(&self) -> String {
-        format!(
-            "{:x}",
-            md5::Md5::digest(format!(
-                "{}{}",
-                match &self.value {
-                    Some(v) => {
-                        v
-                    }
-                    None => {
-                        "None"
-                    }
-                },
-                match &self.rich_text {
-                    Some(v) => {
-                        v.get_hash_code()
-                    }
-                    None => {
-                        "None".into()
-                    }
-                },
-            ))
-        )
+    pub fn set_value_from_u16_ref(&mut self, value: &u16) -> &mut Self {
+        self.set_value_from_numberic(value.clone())
+    }
+
+    pub fn set_value_from_u32(&mut self, value: u32) -> &mut Self {
+        self.set_value_from_numberic(value)
+    }
+
+    pub fn set_value_from_u32_ref(&mut self, value: &u32) -> &mut Self {
+        self.set_value_from_numberic(value.clone())
+    }
+
+    pub fn set_value_from_u64(&mut self, value: u64) -> &mut Self {
+        self.set_value_from_numberic(value as f64)
+    }
+
+    pub fn set_value_from_u64_ref(&mut self, value: &u64) -> &mut Self {
+        self.set_value_from_numberic(value.clone() as f64)
+    }
+
+    pub fn set_value_from_i16(&mut self, value: i16) -> &mut Self {
+        self.set_value_from_numberic(value)
+    }
+
+    pub fn set_value_from_i16_ref(&mut self, value: &i16) -> &mut Self {
+        self.set_value_from_numberic(value.clone())
+    }
+
+    pub fn set_value_from_i32(&mut self, value: i32) -> &mut Self {
+        self.set_value_from_numberic(value)
+    }
+
+    pub fn set_value_from_i32_ref(&mut self, value: &i32) -> &mut Self {
+        self.set_value_from_numberic(value.clone())
+    }
+
+    pub fn set_value_from_i64(&mut self, value: i64) -> &mut Self {
+        self.set_value_from_numberic(value as f64)
+    }
+
+    pub fn set_value_from_i64_ref(&mut self, value: &i64) -> &mut Self {
+        self.set_value_from_numberic(value.clone() as f64)
+    }
+
+    pub fn set_value_from_usize(&mut self, value: usize) -> &mut Self {
+        self.set_value_from_numberic(value as f64)
+    }
+
+    pub fn set_value_from_usize_ref(&mut self, value: &usize) -> &mut Self {
+        self.set_value_from_numberic(value.clone() as f64)
+    }
+
+    pub(crate) fn guess_typed_data(value: &str) -> CellRawValue {
+        let uppercase_value = value.to_uppercase();
+
+        // Match the value against a few data types
+        if uppercase_value == "NULL" {
+            return CellRawValue::Null;
+        }
+
+        if let Ok(f) = value.parse::<f64>() {
+            return CellRawValue::Numeric(f);
+        }
+
+        if uppercase_value == "TRUE" {
+            return CellRawValue::Bool(true);
+        }
+
+        if uppercase_value == "FALSE" {
+            return CellRawValue::Bool(false);
+        }
+
+        CellRawValue::String(value.into())
     }
 
     pub(crate) fn is_empty(&self) -> bool {
-        match &self.value {
-            Some(_) => return false,
-            None => {}
-        }
-        match &self.rich_text {
-            Some(_) => return false,
-            None => {}
+        if &self.raw_value != &CellRawValue::Null {
+            return false;
         }
         match &self.formula {
             Some(_) => return false,
