@@ -30,6 +30,7 @@ use structs::drawing::charts::OrientationValues;
 use structs::drawing::charts::Pie3DChart;
 use structs::drawing::charts::PieChart;
 use structs::drawing::charts::PlotArea;
+use structs::drawing::charts::PrintSettings;
 use structs::drawing::charts::RadarChart;
 use structs::drawing::charts::RightAngleAxes;
 use structs::drawing::charts::RotateX;
@@ -54,12 +55,9 @@ use structs::drawing::charts::YValues;
 use structs::drawing::spreadsheet::GraphicFrame;
 use structs::drawing::spreadsheet::MarkerType;
 use structs::drawing::spreadsheet::TwoCellAnchor;
-use structs::drawing::DefaultRunProperties;
-use structs::drawing::EndParagraphRunProperties;
 use structs::drawing::Paragraph;
 use structs::drawing::Run;
 use structs::drawing::RunProperties;
-use structs::drawing::TextCharacterPropertiesType;
 use structs::ChartType;
 
 #[derive(Clone, Debug)]
@@ -83,13 +81,13 @@ pub struct Chart {
 ///
 /// Other types will be supported sequentially.
 ///
-/// ## Add Chart
-/// ![Result Image](https://github.com/MathNya/umya-spreadsheet/raw/master/images/sample3.png)
+/// ## Example
+/// ![Result Image](https://github.com/MathNya/umya-spreadsheet/raw/master/images/chart/chart_title.png)
 /// ```rust
 /// extern crate umya_spreadsheet;
 /// let mut book = umya_spreadsheet::new_file();
 ///
-/// // add chart
+/// // Add Chart
 /// let mut from_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
 /// let mut to_marker = umya_spreadsheet::structs::drawing::spreadsheet::MarkerType::default();
 /// from_marker.set_coordinate("C1");
@@ -105,40 +103,28 @@ pub struct Chart {
 ///     to_marker,
 ///     area_chart_series_list,
 /// );
-/// book.get_sheet_by_name_mut("Sheet7")
-///     .unwrap()
+/// book.get_sheet_by_name_mut("Sheet1").unwrap()
 ///     .add_chart(chart);
-/// ```
 ///
-/// ## Get Chart by Worksheet.
-/// ```rust
-/// extern crate umya_spreadsheet;
-/// let mut book = umya_spreadsheet::new_file();
-///
-/// let worksheet = book.get_sheet_by_name_mut("Sheet7").unwrap();
+/// // Get Chart by Worksheet.
+/// let mut worksheet = book.get_sheet_by_name_mut("Sheet1").unwrap();
 /// let chart = worksheet.get_chart("C1");
-/// let chart = worksheet.get_chart_by_column_and_row(3, 1);
+/// let chart = worksheet.get_chart_by_column_and_row(&3, &1);
 /// let chart = worksheet.get_chart_mut("C1");
-/// let chart = worksheet.get_chart_by_column_and_row_mut(3, 1);
+/// let chart = worksheet.get_chart_by_column_and_row_mut(&3, &1);
 ///
 /// // Use this if there are multiple Charts in a given cell.
 /// let charts = worksheet.get_charts("C1");
-/// let charts = worksheet.get_charts_by_column_and_row(3, 1);
+/// let charts = worksheet.get_charts_by_column_and_row(&3, &1);
 /// let charts = worksheet.get_charts_mut("C1");
-/// let charts = worksheet.get_charts_by_column_and_row_mut(3, 1);
-/// ```
+/// let charts = worksheet.get_charts_by_column_and_row_mut(&3, &1);
 ///
-/// ## Set Chart Title, Series Title, Horizonal Title and Vertical Title.
-/// ![Result Image](https://github.com/MathNya/umya-spreadsheet/raw/master/images/chart/chart_title.png)
-/// ```rust
-/// extern crate umya_spreadsheet;
-/// let mut book = umya_spreadsheet::new_file();
-///
-/// let mut chart = book.get_sheet_by_name_mut("Sheet7").get_chart_mut("C1").unwrap();
+/// // Set Chart Title, Series Title, Horizonal Title and Vertical Title.
+/// let mut chart = book.get_sheet_by_name_mut("Sheet1").unwrap().get_chart_mut("C1").unwrap();
 /// chart
 ///     .set_series_title(vec!["Line1", "Line2"])
 ///     .set_series_point_title(vec!["Point1", "Point2", "Point3", "Point4"])
-///     .set_name("Chart Title")
+///     .set_title("Chart Title")
 ///     .set_horizontal_title("Horizontal Title")
 ///     .set_vertical_title("Vertical Title");
 /// ```
@@ -370,34 +356,41 @@ impl Chart {
         self.two_cell_anchor.get_from_marker().get_row()
     }
 
-    fn convert_series(&self, area_chart_series_list: Vec<&str>, smooth: bool) -> AreaChartSeriesList {
+    fn convert_series(
+        &self,
+        area_chart_series_list: Vec<&str>,
+        smooth: bool,
+    ) -> AreaChartSeriesList {
         let mut acsl_obj = AreaChartSeriesList::default();
-        area_chart_series_list.into_iter().enumerate().for_each(|(idx, area_chart_series)| {
-            let mut values = Values::default();
-            values
-                .get_number_reference_mut()
-                .get_formula_mut()
-                .get_address_mut()
-                .set_address(area_chart_series);
-            values
-                .get_number_reference_mut()
-                .get_numbering_cache_mut()
-                .get_format_code_mut()
-                .set_text("General");
+        area_chart_series_list
+            .into_iter()
+            .enumerate()
+            .for_each(|(idx, area_chart_series)| {
+                let mut values = Values::default();
+                values
+                    .get_number_reference_mut()
+                    .get_formula_mut()
+                    .get_address_mut()
+                    .set_address(area_chart_series);
+                values
+                    .get_number_reference_mut()
+                    .get_numbering_cache_mut()
+                    .get_format_code_mut()
+                    .set_text("General");
 
-            let mut acs_obj = AreaChartSeries::default();
-            acs_obj.get_index_mut().set_val(idx as u32);
-            acs_obj.get_order_mut().set_val(idx as u32);
-            acs_obj.set_values(values);
-            if smooth {
-                acs_obj.set_smooth(Smooth::default());
-            } else {
-                let mut invert_if_negative = InvertIfNegative::default();
-                invert_if_negative.set_val(0f64);
-                acs_obj.set_invert_if_negative(invert_if_negative);
-            }
-            acsl_obj.add_area_chart_series(acs_obj);
-        });
+                let mut acs_obj = AreaChartSeries::default();
+                acs_obj.get_index_mut().set_val(idx as u32);
+                acs_obj.get_order_mut().set_val(idx as u32);
+                acs_obj.set_values(values);
+                if smooth {
+                    acs_obj.set_smooth(Smooth::default());
+                } else {
+                    let mut invert_if_negative = InvertIfNegative::default();
+                    invert_if_negative.set_val(0f64);
+                    acs_obj.set_invert_if_negative(invert_if_negative);
+                }
+                acsl_obj.add_area_chart_series(acs_obj);
+            });
         acsl_obj
     }
 
@@ -532,14 +525,7 @@ impl Chart {
             .get_graphic_mut()
             .get_graphic_data_mut()
             .get_chart_space_mut()
-            .get_print_settings_mut()
-            .get_page_margins_mut()
-            .set_bottom(0.75)
-            .set_left(0.7)
-            .set_right(0.7)
-            .set_top(0.75)
-            .set_header(0.3)
-            .set_footer(0.3);
+            .set_print_settings(self.make_print_settings());
         self.two_cell_anchor.set_graphic_frame(graphic_frame);
     }
 
@@ -690,14 +676,7 @@ impl Chart {
             .get_graphic_mut()
             .get_graphic_data_mut()
             .get_chart_space_mut()
-            .get_print_settings_mut()
-            .get_page_margins_mut()
-            .set_bottom(0.75)
-            .set_left(0.7)
-            .set_right(0.7)
-            .set_top(0.75)
-            .set_header(0.3)
-            .set_footer(0.3);
+            .set_print_settings(self.make_print_settings());
         self.two_cell_anchor.set_graphic_frame(graphic_frame);
     }
 
@@ -716,8 +695,8 @@ impl Chart {
 
         let layout = Layout::default();
 
-        let default_run_properties = DefaultRunProperties::default();
-        let mut end_paragraph_run_properties = EndParagraphRunProperties::default();
+        let default_run_properties = RunProperties::default();
+        let mut end_paragraph_run_properties = RunProperties::default();
         end_paragraph_run_properties.set_language(&self.default_language);
         let mut paragraph = Paragraph::default();
         paragraph
@@ -785,14 +764,7 @@ impl Chart {
             .get_graphic_mut()
             .get_graphic_data_mut()
             .get_chart_space_mut()
-            .get_print_settings_mut()
-            .get_page_margins_mut()
-            .set_bottom(0.75)
-            .set_left(0.7)
-            .set_right(0.7)
-            .set_top(0.75)
-            .set_header(0.3)
-            .set_footer(0.3);
+            .set_print_settings(self.make_print_settings());
         self.two_cell_anchor.set_graphic_frame(graphic_frame);
     }
 
@@ -822,8 +794,8 @@ impl Chart {
 
         let layout = Layout::default();
 
-        let default_run_properties = DefaultRunProperties::default();
-        let mut end_paragraph_run_properties = EndParagraphRunProperties::default();
+        let default_run_properties = RunProperties::default();
+        let mut end_paragraph_run_properties = RunProperties::default();
         end_paragraph_run_properties.set_language(&self.default_language);
         let mut paragraph = Paragraph::default();
         paragraph
@@ -897,14 +869,7 @@ impl Chart {
             .get_graphic_mut()
             .get_graphic_data_mut()
             .get_chart_space_mut()
-            .get_print_settings_mut()
-            .get_page_margins_mut()
-            .set_bottom(0.75)
-            .set_left(0.7)
-            .set_right(0.7)
-            .set_top(0.75)
-            .set_header(0.3)
-            .set_footer(0.3);
+            .set_print_settings(self.make_print_settings());
         self.two_cell_anchor.set_graphic_frame(graphic_frame);
     }
 
@@ -1010,14 +975,7 @@ impl Chart {
             .get_graphic_mut()
             .get_graphic_data_mut()
             .get_chart_space_mut()
-            .get_print_settings_mut()
-            .get_page_margins_mut()
-            .set_bottom(0.75)
-            .set_left(0.7)
-            .set_right(0.7)
-            .set_top(0.75)
-            .set_header(0.3)
-            .set_footer(0.3);
+            .set_print_settings(self.make_print_settings());
         self.two_cell_anchor.set_graphic_frame(graphic_frame);
     }
 
@@ -1145,14 +1103,7 @@ impl Chart {
             .get_graphic_mut()
             .get_graphic_data_mut()
             .get_chart_space_mut()
-            .get_print_settings_mut()
-            .get_page_margins_mut()
-            .set_bottom(0.75)
-            .set_left(0.7)
-            .set_right(0.7)
-            .set_top(0.75)
-            .set_header(0.3)
-            .set_footer(0.3);
+            .set_print_settings(self.make_print_settings());
         self.two_cell_anchor.set_graphic_frame(graphic_frame);
     }
 
@@ -1297,14 +1248,7 @@ impl Chart {
             .get_graphic_mut()
             .get_graphic_data_mut()
             .get_chart_space_mut()
-            .get_print_settings_mut()
-            .get_page_margins_mut()
-            .set_bottom(0.75)
-            .set_left(0.7)
-            .set_right(0.7)
-            .set_top(0.75)
-            .set_header(0.3)
-            .set_footer(0.3);
+            .set_print_settings(self.make_print_settings());
         self.two_cell_anchor.set_graphic_frame(graphic_frame);
     }
 
@@ -1437,14 +1381,7 @@ impl Chart {
             .get_graphic_mut()
             .get_graphic_data_mut()
             .get_chart_space_mut()
-            .get_print_settings_mut()
-            .get_page_margins_mut()
-            .set_bottom(0.75)
-            .set_left(0.7)
-            .set_right(0.7)
-            .set_top(0.75)
-            .set_header(0.3)
-            .set_footer(0.3);
+            .set_print_settings(self.make_print_settings());
         self.two_cell_anchor.set_graphic_frame(graphic_frame);
     }
 
@@ -1594,14 +1531,7 @@ impl Chart {
             .get_graphic_mut()
             .get_graphic_data_mut()
             .get_chart_space_mut()
-            .get_print_settings_mut()
-            .get_page_margins_mut()
-            .set_bottom(0.75)
-            .set_left(0.7)
-            .set_right(0.7)
-            .set_top(0.75)
-            .set_header(0.3)
-            .set_footer(0.3);
+            .set_print_settings(self.make_print_settings());
         self.two_cell_anchor.set_graphic_frame(graphic_frame);
     }
 
@@ -1619,8 +1549,8 @@ impl Chart {
             .get_data_labels_mut()
             .set_show_leader_lines(show_leader_lines);
 
-        let default_run_properties = DefaultRunProperties::default();
-        let mut end_paragraph_run_properties = EndParagraphRunProperties::default();
+        let default_run_properties = RunProperties::default();
+        let mut end_paragraph_run_properties = RunProperties::default();
         end_paragraph_run_properties.set_language(&self.default_language);
         let mut paragraph = Paragraph::default();
         paragraph
@@ -1681,14 +1611,7 @@ impl Chart {
             .get_graphic_mut()
             .get_graphic_data_mut()
             .get_chart_space_mut()
-            .get_print_settings_mut()
-            .get_page_margins_mut()
-            .set_bottom(0.75)
-            .set_left(0.7)
-            .set_right(0.7)
-            .set_top(0.75)
-            .set_header(0.3)
-            .set_footer(0.3);
+            .set_print_settings(self.make_print_settings());
         self.two_cell_anchor.set_graphic_frame(graphic_frame);
     }
 
@@ -1838,8 +1761,8 @@ impl Chart {
             .get_cross_between_mut()
             .set_val(CrossBetweenValues::MidpointCategory);
 
-        let default_run_properties = DefaultRunProperties::default();
-        let mut end_paragraph_run_properties = EndParagraphRunProperties::default();
+        let default_run_properties = RunProperties::default();
+        let mut end_paragraph_run_properties = RunProperties::default();
         end_paragraph_run_properties.set_language(&self.default_language);
         let mut paragraph = Paragraph::default();
         paragraph
@@ -1914,14 +1837,7 @@ impl Chart {
             .get_graphic_mut()
             .get_graphic_data_mut()
             .get_chart_space_mut()
-            .get_print_settings_mut()
-            .get_page_margins_mut()
-            .set_bottom(0.75)
-            .set_left(0.7)
-            .set_right(0.7)
-            .set_top(0.75)
-            .set_header(0.3)
-            .set_footer(0.3);
+            .set_print_settings(self.make_print_settings());
         self.two_cell_anchor.set_graphic_frame(graphic_frame);
     }
 
@@ -2052,14 +1968,7 @@ impl Chart {
             .get_graphic_mut()
             .get_graphic_data_mut()
             .get_chart_space_mut()
-            .get_print_settings_mut()
-            .get_page_margins_mut()
-            .set_bottom(0.75)
-            .set_left(0.7)
-            .set_right(0.7)
-            .set_top(0.75)
-            .set_header(0.3)
-            .set_footer(0.3);
+            .set_print_settings(self.make_print_settings());
         self.two_cell_anchor.set_graphic_frame(graphic_frame);
     }
 
@@ -2246,15 +2155,20 @@ impl Chart {
             .get_graphic_mut()
             .get_graphic_data_mut()
             .get_chart_space_mut()
-            .get_print_settings_mut()
-            .get_page_margins_mut()
+            .set_print_settings(self.make_print_settings());
+        self.two_cell_anchor.set_graphic_frame(graphic_frame);
+    }
+
+    pub(crate) fn make_print_settings(&self) -> PrintSettings {
+        let mut obj = PrintSettings::default();
+        obj.get_page_margins_mut()
             .set_bottom(0.75)
             .set_left(0.7)
             .set_right(0.7)
             .set_top(0.75)
             .set_header(0.3)
             .set_footer(0.3);
-        self.two_cell_anchor.set_graphic_frame(graphic_frame);
+        obj
     }
 
     pub(crate) fn make_title<S: Into<String>>(&self, value: S) -> Title {
@@ -2266,7 +2180,7 @@ impl Chart {
         run.set_run_properties(run_properties);
         run.set_text(value);
 
-        let default_run_properties = DefaultRunProperties::default();
+        let default_run_properties = RunProperties::default();
 
         let mut paragraph = Paragraph::default();
         paragraph
