@@ -1,7 +1,6 @@
 // color
 use super::DoubleValue;
 use super::StringValue;
-use super::Theme;
 use super::UInt32Value;
 use md5::Digest;
 use quick_xml::events::BytesStart;
@@ -9,6 +8,7 @@ use quick_xml::Reader;
 use quick_xml::Writer;
 use reader::driver::*;
 use std::io::Cursor;
+use structs::drawing::Theme;
 use writer::driver::*;
 
 const INDEXED_COLORS: &[&str] = &[
@@ -226,15 +226,18 @@ impl Color {
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>, tag_name: &str) {
         let mut attributes: Vec<(&str, &str)> = Vec::new();
+        let theme_index = self.theme_index.get_value_string();
+        let indexed = self.indexed.get_value_string();
         if self.theme_index.has_value() {
-            attributes.push(("theme", self.theme_index.get_value_string()));
+            attributes.push(("theme", &theme_index));
         } else if self.indexed.has_value() {
-            attributes.push(("indexed", self.indexed.get_value_string()));
+            attributes.push(("indexed", &indexed));
         } else if self.argb.has_value() {
             attributes.push(("rgb", self.argb.get_value_string()));
         }
+        let tint = self.tint.get_value_string();
         if self.tint.has_value() {
-            attributes.push(("tint", self.tint.get_value_string()));
+            attributes.push(("tint", &tint));
         }
 
         if !attributes.is_empty() {
