@@ -11,12 +11,12 @@ use structs::Cells;
 
 #[derive(Clone, Debug)]
 pub struct Column {
-    pub(crate) col_num: UInt32Value,
+    col_num: UInt32Value,
     pub(crate) width: DoubleValue,
     pub(crate) hidden: BooleanValue,
     pub(crate) best_fit: BooleanValue,
-    pub(crate) style: Style,
-    pub(crate) auto_width: BooleanValue,
+    style: Style,
+    auto_width: BooleanValue,
 }
 impl Default for Column {
     fn default() -> Self {
@@ -105,7 +105,11 @@ impl Column {
         };
 
         let mut cell_list = cells.get_collection_by_column(self.get_col_num());
-        cell_list.sort_by(|a, b| a.get_coordinate().get_row_num().cmp(b.get_coordinate().get_row_num()));
+        cell_list.sort_by(|a, b| {
+            a.get_coordinate()
+                .get_row_num()
+                .cmp(b.get_coordinate().get_row_num())
+        });
         for cell in cell_list {
             let column_width = cell.get_width_point(&column_font_size);
 
@@ -149,11 +153,10 @@ impl Column {
         format!(
             "{:x}",
             md5::Md5::digest(format!(
-                "{}{}{}{}",
+                "{}{}{}",
                 &self.width.get_value_string(),
                 &self.hidden.get_value_string(),
                 &self.best_fit.get_value_string(),
-                &self.style.get_hash_code(),
             ))
         )
     }
