@@ -77,8 +77,8 @@ impl Comment {
         root_row_num: &u32,
         offset_row_num: &u32,
     ) {
-        let org_col_num = self.coordinate.get_col_num().clone();
-        let org_row_num = self.coordinate.get_row_num().clone();
+        let org_col_num = *self.coordinate.get_col_num();
+        let org_row_num = *self.coordinate.get_row_num();
         self.coordinate.adjustment_insert_coordinate(
             root_col_num,
             offset_col_num,
@@ -87,14 +87,14 @@ impl Comment {
         );
         if &org_col_num != self.coordinate.get_col_num() {
             self.get_anchor_mut()
-                .adjustment_insert_colmun(offset_col_num);
+                .adjustment_insert_column(offset_col_num);
             match self
                 .get_shape_mut()
                 .get_client_data_mut()
                 .get_comment_column_target_mut()
             {
                 Some(v) => {
-                    v.adjustment_insert_colmun(offset_col_num);
+                    v.adjustment_insert_column(offset_col_num);
                 }
                 None => {}
             }
@@ -121,8 +121,8 @@ impl Comment {
         root_row_num: &u32,
         offset_row_num: &u32,
     ) {
-        let org_col_num = self.coordinate.get_col_num().clone();
-        let org_row_num = self.coordinate.get_row_num().clone();
+        let org_col_num = *self.coordinate.get_col_num();
+        let org_row_num = *self.coordinate.get_row_num();
         self.coordinate.adjustment_remove_coordinate(
             root_col_num,
             offset_col_num,
@@ -131,14 +131,14 @@ impl Comment {
         );
         if &org_col_num != self.coordinate.get_col_num() {
             self.get_anchor_mut()
-                .adjustment_remove_colmun(offset_col_num);
+                .adjustment_remove_column(offset_col_num);
             match self
                 .get_shape_mut()
                 .get_client_data_mut()
                 .get_comment_column_target_mut()
             {
                 Some(v) => {
-                    v.adjustment_remove_colmun(offset_col_num);
+                    v.adjustment_remove_column(offset_col_num);
                 }
                 None => {}
             }
