@@ -9,7 +9,7 @@ pub struct Coordinate {
 }
 impl Coordinate {
     pub fn get_col_num(&self) -> &u32 {
-        &self.column.get_num()
+        self.column.get_num()
     }
 
     pub fn set_col_num(&mut self, value: u32) -> &mut Self {
@@ -18,7 +18,7 @@ impl Coordinate {
     }
 
     pub fn get_row_num(&self) -> &u32 {
-        &self.row.get_num()
+        self.row.get_num()
     }
 
     pub fn set_row_num(&mut self, value: u32) -> &mut Self {
@@ -44,28 +44,27 @@ impl Coordinate {
         self
     }
 
-    pub fn set_coordinate<S: Into<String>>(&mut self, value: S) -> &mut Self {
-        let result = index_from_coordinate(value.into());
-        self.column.set_num(result[0].unwrap());
-        self.row.set_num(result[1].unwrap());
-        self.column.set_is_lock_usize(result[2].unwrap());
-        self.row.set_is_lock_usize(result[3].unwrap());
+    pub fn set_coordinate<S: AsRef<str>>(&mut self, value: S) -> &mut Self {
+        let result = index_from_coordinate(value.as_ref());
+        if let [c, r, cl, rl] = result[0..4] {
+            self.column.set_num(c.unwrap());
+            self.row.set_num(r.unwrap());
+            self.column.set_is_lock_usize(cl.unwrap());
+            self.row.set_is_lock_usize(rl.unwrap());
+        };
+
         self
     }
 
     pub fn get_coordinate(&self) -> String {
         coordinate_from_index_with_lock(
-            &self.column.get_num(),
-            &self.row.get_num(),
-            &self.column.get_is_lock(),
-            &self.row.get_is_lock(),
+            self.column.get_num(),
+            self.row.get_num(),
+            self.column.get_is_lock(),
+            self.row.get_is_lock(),
         )
     }
 
-    pub(crate) fn is_mine(&self, col_num: &u32, row_num: &u32) -> bool {
-        self.column.is_mine(col_num) && self.row.is_mine(row_num)
-    }
-
     pub(crate) fn adjustment_insert_coordinate(
         &mut self,
         root_col_num: &u32,
