@@ -24,7 +24,7 @@ impl Alpha {
         _reader: &mut Reader<R>,
         e: &BytesStart,
     ) {
-        &mut self.set_val(get_attribute(e, b"val").unwrap());
+        self.set_val(get_attribute(e, b"val").unwrap());
     }
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
