@@ -5,33 +5,35 @@ use quick_xml::Writer;
 use reader::driver::*;
 use std::io::Cursor;
 use structs::raw::RawRelationships;
-use structs::Image;
+use structs::MediaObject;
 use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
 pub struct Blip {
-    image: Image,
+    image: MediaObject,
     cstate: String,
 }
 impl Blip {
-    pub fn get_image(&self) -> &Image {
+    pub fn get_image(&self) -> &MediaObject {
         &self.image
     }
 
-    pub fn get_image_mut(&mut self) -> &mut Image {
+    pub fn get_image_mut(&mut self) -> &mut MediaObject {
         &mut self.image
     }
 
-    pub fn set_image(&mut self, value: Image) {
+    pub fn set_image(&mut self, value: MediaObject) -> &mut Self {
         self.image = value;
+        self
     }
 
     pub fn get_cstate(&self) -> &str {
         &self.cstate
     }
 
-    pub fn set_cstate<S: Into<String>>(&mut self, value: S) {
+    pub fn set_cstate<S: Into<String>>(&mut self, value: S) -> &mut Self {
         self.cstate = value.into();
+        self
     }
 
     pub(crate) fn set_attributes<R: std::io::BufRead>(
@@ -48,7 +50,7 @@ impl Blip {
         }
 
         let picture_id = get_attribute(e, b"r:embed").unwrap();
-        let relationship = drawing_relationships.get_relationship_by_rid(picture_id);
+        let relationship = drawing_relationships.get_relationship_by_rid(&picture_id);
         self.get_image_mut()
             .set_image_name(relationship.get_raw_file().get_file_name());
         self.get_image_mut()
@@ -64,7 +66,7 @@ impl Blip {
             "http://schemas.openxmlformats.org/officeDocument/2006/relationships",
         ));
         attributes.push(("r:embed", r_id_str.as_str()));
-        if &self.cstate != "" {
+        if !&self.cstate.is_empty() {
             attributes.push(("cstate", &self.cstate));
         }
         write_start_tag(writer, "a:blip", attributes, false);
