@@ -14,7 +14,7 @@ pub struct BarDirection {
 }
 impl BarDirection {
     pub fn get_val(&self) -> &BarDirectionValues {
-        &self.val.get_value()
+        self.val.get_value()
     }
 
     pub fn set_val(&mut self, value: BarDirectionValues) -> &mut BarDirection {
@@ -35,7 +35,7 @@ impl BarDirection {
         write_start_tag(
             writer,
             "c:barDir",
-            vec![("val", &self.val.get_value_string())],
+            vec![("val", self.val.get_value_string())],
             true,
         );
     }
