@@ -34,7 +34,7 @@ impl BubbleScale {
         write_start_tag(
             writer,
             "c:bubbleScale",
-            vec![("val", self.val.get_value_string())],
+            vec![("val", &self.val.get_value_string())],
             true,
         );
     }
