@@ -14,7 +14,7 @@ pub struct CrossBetween {
 }
 impl CrossBetween {
     pub fn get_val(&self) -> &CrossBetweenValues {
-        &self.val.get_value()
+        self.val.get_value()
     }
 
     pub fn set_val(&mut self, value: CrossBetweenValues) -> &mut CrossBetween {
@@ -35,7 +35,7 @@ impl CrossBetween {
         write_start_tag(
             writer,
             "c:crossBetween",
-            vec![("val", &self.val.get_value_string())],
+            vec![("val", self.val.get_value_string())],
             true,
         );
     }
