@@ -13,7 +13,7 @@ pub struct Date1904 {
 }
 impl Date1904 {
     pub fn get_val(&self) -> &bool {
-        &self.val.get_value()
+        self.val.get_value()
     }
 
     pub fn set_val(&mut self, value: bool) -> &mut Date1904 {
@@ -34,7 +34,7 @@ impl Date1904 {
         write_start_tag(
             writer,
             "c:date1904",
-            vec![("val", &self.val.get_value_string())],
+            vec![("val", self.val.get_value_string())],
             true,
         );
     }
