@@ -14,7 +14,7 @@ pub struct MajorTickMark {
 }
 impl MajorTickMark {
     pub fn get_val(&self) -> &TickMarkValues {
-        &self.val.get_value()
+        self.val.get_value()
     }
 
     pub fn set_val(&mut self, value: TickMarkValues) -> &mut MajorTickMark {
@@ -35,7 +35,7 @@ impl MajorTickMark {
         write_start_tag(
             writer,
             "c:majorTickMark",
-            vec![("val", &self.val.get_value_string())],
+            vec![("val", self.val.get_value_string())],
             true,
         );
     }
