@@ -93,12 +93,12 @@ impl PageMargins {
             writer,
             "c:pageMargins",
             vec![
-                ("b", self.bottom.get_value_string()),
-                ("l", self.left.get_value_string()),
-                ("r", self.right.get_value_string()),
-                ("t", self.top.get_value_string()),
-                ("header", self.header.get_value_string()),
-                ("footer", self.footer.get_value_string()),
+                ("b", &self.bottom.get_value_string()),
+                ("l", &self.left.get_value_string()),
+                ("r", &self.right.get_value_string()),
+                ("t", &self.top.get_value_string()),
+                ("header", &self.header.get_value_string()),
+                ("footer", &self.footer.get_value_string()),
             ],
             true,
         );
