@@ -14,7 +14,7 @@ pub struct RadarStyle {
 }
 impl RadarStyle {
     pub fn get_val(&self) -> &RadarStyleValues {
-        &self.val.get_value()
+        self.val.get_value()
     }
 
     pub fn set_val(&mut self, value: RadarStyleValues) -> &mut RadarStyle {
@@ -35,7 +35,7 @@ impl RadarStyle {
         write_start_tag(
             writer,
             "c:radarStyle",
-            vec![("val", &self.val.get_value_string())],
+            vec![("val", self.val.get_value_string())],
             true,
         );
     }
