@@ -1,4 +1,5 @@
 // c:sideWall
+use super::ShapeProperties;
 use super::Thickness;
 use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
@@ -9,6 +10,7 @@ use writer::driver::*;
 #[derive(Clone, Default, Debug)]
 pub struct SideWall {
     thickness: Option<Thickness>,
+    shape_properties: Option<ShapeProperties>,
 }
 impl SideWall {
     pub fn get_thickness(&self) -> &Option<Thickness> {
@@ -24,6 +26,19 @@ impl SideWall {
         self
     }
 
+    pub fn get_shape_properties(&self) -> &Option<ShapeProperties> {
+        &self.shape_properties
+    }
+
+    pub fn get_shape_properties_mut(&mut self) -> &mut Option<ShapeProperties> {
+        &mut self.shape_properties
+    }
+
+    pub fn set_shape_properties(&mut self, value: ShapeProperties) -> &mut Self {
+        self.shape_properties = Some(value);
+        self
+    }
+
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
         reader: &mut Reader<R>,
@@ -40,6 +55,14 @@ impl SideWall {
                     }
                     _ => (),
                 },
+                Ok(Event::Start(ref e)) => match e.name() {
+                    b"c:spPr" => {
+                        let mut obj = ShapeProperties::default();
+                        obj.set_attributes(reader, e);
+                        self.set_shape_properties(obj);
+                    }
+                    _ => (),
+                },
                 Ok(Event::End(ref e)) => match e.name() {
                     b"c:sideWall" => return,
                     _ => (),
@@ -64,6 +87,14 @@ impl SideWall {
             None => {}
         }
 
+        // c:spPr
+        match &self.shape_properties {
+            Some(v) => {
+                v.write_to(writer);
+            }
+            None => {}
+        }
+
         write_end_tag(writer, "c:sideWall");
     }
 }
