@@ -49,8 +49,7 @@ impl StringCache {
             true,
         );
 
-        let mut idx = 0;
-        for cell_value in cell_value_list {
+        for (idx, cell_value) in cell_value_list.into_iter().enumerate() {
             // c:pt
             write_start_tag(
                 writer,
@@ -65,7 +64,6 @@ impl StringCache {
             write_end_tag(writer, "c:v");
 
             write_end_tag(writer, "c:pt");
-            idx += 1;
         }
 
         write_end_tag(writer, "c:strCache");
