@@ -66,12 +66,12 @@ impl TextProperties {
                     b"a:p" => {
                         let mut paragraph = Paragraph::default();
                         paragraph.set_attributes(reader, e);
-                        &mut self.add_paragraph(paragraph);
+                        self.add_paragraph(paragraph);
                     }
                     b"a:bodyPr" => {
                         let mut body_properties = BodyProperties::default();
                         body_properties.set_attributes(reader, e, false);
-                        &mut self.set_body_properties(body_properties);
+                        self.set_body_properties(body_properties);
                     }
                     _ => (),
                 },
@@ -79,7 +79,7 @@ impl TextProperties {
                     b"a:bodyPr" => {
                         let mut body_properties = BodyProperties::default();
                         body_properties.set_attributes(reader, e, true);
-                        &mut self.set_body_properties(body_properties);
+                        self.set_body_properties(body_properties);
                     }
                     _ => (),
                 },
@@ -100,7 +100,7 @@ impl TextProperties {
         write_start_tag(writer, "c:txPr", vec![], false);
 
         // a:bodyPr
-        &self.body_properties.write_to(writer);
+        self.body_properties.write_to(writer);
 
         // a:lstStyle
         write_start_tag(writer, "a:lstStyle", vec![], true);
