@@ -46,8 +46,8 @@ impl Extents {
             writer,
             "a:ext",
             vec![
-                ("cx", self.cx.get_value_string()),
-                ("cy", self.cy.get_value_string()),
+                ("cx", &self.cx.get_value_string()),
+                ("cy", &self.cy.get_value_string()),
             ],
             true,
         );
