@@ -67,7 +67,7 @@ impl Glow {
         write_start_tag(
             writer,
             "a:glow",
-            vec![("rad", self.radius.get_value_string())],
+            vec![("rad", &self.radius.get_value_string())],
             false,
         );
 
