@@ -66,73 +66,75 @@ pub enum PresetCameraValues {
     PerspectiveRight,
 }
 impl Default for PresetCameraValues {
-    fn default() -> Self { Self::LegacyObliqueTopLeft }
+    fn default() -> Self {
+        Self::LegacyObliqueTopLeft
+    }
 }
 impl EnumTrait for PresetCameraValues {
-    fn get_value_string(&self)->&str {
+    fn get_value_string(&self) -> &str {
         match &self {
-            Self::IsometricBottomDown => {"isometricBottomDown"},
-            Self::IsometricBottomUp => {"isometricBottomUp"},
-            Self::IsometricLeftDown => {"isometricLeftDown"},
-            Self::IsometricLeftUp => {"isometricLeftUp"},
-            Self::IsometricOffAxis1Left => {"isometricOffAxis1Left"},
-            Self::IsometricOffAxis1Right => {"isometricOffAxis1Right"},
-            Self::IsometricOffAxis1Top => {"isometricOffAxis1Top"},
-            Self::IsometricOffAxis2Left => {"isometricOffAxis2Left"},
-            Self::IsometricOffAxis2Right => {"isometricOffAxis2Right"},
-            Self::IsometricOffAxis2Top => {"isometricOffAxis2Top"},
-            Self::IsometricOffAxis3Bottom => {"isometricOffAxis3Bottom"},
-            Self::IsometricOffAxis3Left => {"isometricOffAxis3Left"},
-            Self::IsometricOffAxis3Right => {"isometricOffAxis3Right"},
-            Self::IsometricOffAxis4Bottom => {"isometricOffAxis4Bottom"},
-            Self::IsometricOffAxis4Left => {"isometricOffAxis4Left"},
-            Self::IsometricOffAxis4Right => {"isometricOffAxis4Right"},
-            Self::IsometricRightDown => {"isometricRightDown"},
-            Self::IsometricRightUp => {"isometricRightUp"},
-            Self::IsometricTopDown => {"isometricTopDown"},
-            Self::IsometricTopUp => {"isometricTopUp"},
-            Self::LegacyObliqueBottom => {"legacyObliqueBottom"},
-            Self::LegacyObliqueBottomLeft => {"legacyObliqueBottomLeft"},
-            Self::LegacyObliqueBottomRight => {"legacyObliqueBottomRight"},
-            Self::LegacyObliqueFront => {"legacyObliqueFront"},
-            Self::LegacyObliqueLeft => {"legacyObliqueLeft"},
-            Self::LegacyObliqueRight => {"legacyObliqueRight"},
-            Self::LegacyObliqueTop => {"legacyObliqueTop"},
-            Self::LegacyObliqueTopLeft => {"legacyObliqueTopLeft"},
-            Self::LegacyObliqueTopRight => {"legacyObliqueTopRight"},
-            Self::LegacyPerspectiveBottom => {"legacyPerspectiveBottom"},
-            Self::LegacyPerspectiveBottomLeft => {"legacyPerspectiveBottomLeft"},
-            Self::LegacyPerspectiveBottomRight => {"legacyPerspectiveBottomRight"},
-            Self::LegacyPerspectiveFront => {"legacyPerspectiveFront"},
-            Self::LegacyPerspectiveLeft => {"legacyPerspectiveLeft"},
-            Self::LegacyPerspectiveRight => {"legacyPerspectiveRight"},
-            Self::LegacyPerspectiveTop => {"legacyPerspectiveTop"},
-            Self::LegacyPerspectiveTopLeft => {"legacyPerspectiveTopLeft"},
-            Self::LegacyPerspectiveTopRight => {"legacyPerspectiveTopRight"},
-            Self::ObliqueBottom => {"obliqueBottom"},
-            Self::ObliqueBottomLeft => {"obliqueBottomLeft"},
-            Self::ObliqueBottomRight => {"obliqueBottomRight"},
-            Self::ObliqueLeft => {"obliqueLeft"},
-            Self::ObliqueRight => {"obliqueRight"},
-            Self::ObliqueTop => {"obliqueTop"},
-            Self::ObliqueTopLeft => {"obliqueTopLeft"},
-            Self::ObliqueTopRight => {"obliqueTopRight"},
-            Self::OrthographicFront => {"orthographicFront"},
-            Self::PerspectiveAbove => {"perspectiveAbove"},
-            Self::PerspectiveAboveLeftFacing => {"perspectiveAboveLeftFacing"},
-            Self::PerspectiveAboveRightFacing => {"perspectiveAboveRightFacing"},
-            Self::PerspectiveBelow => {"perspectiveBelow"},
-            Self::PerspectiveContrastingLeftFacing => {"perspectiveContrastingLeftFacing"},
-            Self::PerspectiveContrastingRightFacing => {"perspectiveContrastingRightFacing"},
-            Self::PerspectiveFront => {"perspectiveFront"},
-            Self::PerspectiveHeroicExtremeLeftFacing => {"perspectiveHeroicExtremeLeftFacing"},
-            Self::PerspectiveHeroicExtremeRightFacing => {"perspectiveHeroicExtremeRightFacing"},
-            Self::PerspectiveHeroicLeftFacing => {"perspectiveHeroicLeftFacing"},
-            Self::PerspectiveHeroicRightFacing => {"perspectiveHeroicRightFacing"},
-            Self::PerspectiveLeft => {"perspectiveLeft"},
-            Self::PerspectiveRelaxed => {"perspectiveRelaxed"},
-            Self::PerspectiveRelaxedModerately => {"perspectiveRelaxedModerately"},
-            Self::PerspectiveRight => {"perspectiveRight"},
+            Self::IsometricBottomDown => "isometricBottomDown",
+            Self::IsometricBottomUp => "isometricBottomUp",
+            Self::IsometricLeftDown => "isometricLeftDown",
+            Self::IsometricLeftUp => "isometricLeftUp",
+            Self::IsometricOffAxis1Left => "isometricOffAxis1Left",
+            Self::IsometricOffAxis1Right => "isometricOffAxis1Right",
+            Self::IsometricOffAxis1Top => "isometricOffAxis1Top",
+            Self::IsometricOffAxis2Left => "isometricOffAxis2Left",
+            Self::IsometricOffAxis2Right => "isometricOffAxis2Right",
+            Self::IsometricOffAxis2Top => "isometricOffAxis2Top",
+            Self::IsometricOffAxis3Bottom => "isometricOffAxis3Bottom",
+            Self::IsometricOffAxis3Left => "isometricOffAxis3Left",
+            Self::IsometricOffAxis3Right => "isometricOffAxis3Right",
+            Self::IsometricOffAxis4Bottom => "isometricOffAxis4Bottom",
+            Self::IsometricOffAxis4Left => "isometricOffAxis4Left",
+            Self::IsometricOffAxis4Right => "isometricOffAxis4Right",
+            Self::IsometricRightDown => "isometricRightDown",
+            Self::IsometricRightUp => "isometricRightUp",
+            Self::IsometricTopDown => "isometricTopDown",
+            Self::IsometricTopUp => "isometricTopUp",
+            Self::LegacyObliqueBottom => "legacyObliqueBottom",
+            Self::LegacyObliqueBottomLeft => "legacyObliqueBottomLeft",
+            Self::LegacyObliqueBottomRight => "legacyObliqueBottomRight",
+            Self::LegacyObliqueFront => "legacyObliqueFront",
+            Self::LegacyObliqueLeft => "legacyObliqueLeft",
+            Self::LegacyObliqueRight => "legacyObliqueRight",
+            Self::LegacyObliqueTop => "legacyObliqueTop",
+            Self::LegacyObliqueTopLeft => "legacyObliqueTopLeft",
+            Self::LegacyObliqueTopRight => "legacyObliqueTopRight",
+            Self::LegacyPerspectiveBottom => "legacyPerspectiveBottom",
+            Self::LegacyPerspectiveBottomLeft => "legacyPerspectiveBottomLeft",
+            Self::LegacyPerspectiveBottomRight => "legacyPerspectiveBottomRight",
+            Self::LegacyPerspectiveFront => "legacyPerspectiveFront",
+            Self::LegacyPerspectiveLeft => "legacyPerspectiveLeft",
+            Self::LegacyPerspectiveRight => "legacyPerspectiveRight",
+            Self::LegacyPerspectiveTop => "legacyPerspectiveTop",
+            Self::LegacyPerspectiveTopLeft => "legacyPerspectiveTopLeft",
+            Self::LegacyPerspectiveTopRight => "legacyPerspectiveTopRight",
+            Self::ObliqueBottom => "obliqueBottom",
+            Self::ObliqueBottomLeft => "obliqueBottomLeft",
+            Self::ObliqueBottomRight => "obliqueBottomRight",
+            Self::ObliqueLeft => "obliqueLeft",
+            Self::ObliqueRight => "obliqueRight",
+            Self::ObliqueTop => "obliqueTop",
+            Self::ObliqueTopLeft => "obliqueTopLeft",
+            Self::ObliqueTopRight => "obliqueTopRight",
+            Self::OrthographicFront => "orthographicFront",
+            Self::PerspectiveAbove => "perspectiveAbove",
+            Self::PerspectiveAboveLeftFacing => "perspectiveAboveLeftFacing",
+            Self::PerspectiveAboveRightFacing => "perspectiveAboveRightFacing",
+            Self::PerspectiveBelow => "perspectiveBelow",
+            Self::PerspectiveContrastingLeftFacing => "perspectiveContrastingLeftFacing",
+            Self::PerspectiveContrastingRightFacing => "perspectiveContrastingRightFacing",
+            Self::PerspectiveFront => "perspectiveFront",
+            Self::PerspectiveHeroicExtremeLeftFacing => "perspectiveHeroicExtremeLeftFacing",
+            Self::PerspectiveHeroicExtremeRightFacing => "perspectiveHeroicExtremeRightFacing",
+            Self::PerspectiveHeroicLeftFacing => "perspectiveHeroicLeftFacing",
+            Self::PerspectiveHeroicRightFacing => "perspectiveHeroicRightFacing",
+            Self::PerspectiveLeft => "perspectiveLeft",
+            Self::PerspectiveRelaxed => "perspectiveRelaxed",
+            Self::PerspectiveRelaxedModerately => "perspectiveRelaxedModerately",
+            Self::PerspectiveRight => "perspectiveRight",
         }
     }
 }
@@ -202,7 +204,7 @@ impl FromStr for PresetCameraValues {
             "perspectiveRelaxed" => Ok(Self::PerspectiveRelaxed),
             "perspectiveRelaxedModerately" => Ok(Self::PerspectiveRelaxedModerately),
             "perspectiveRight" => Ok(Self::PerspectiveRight),
-            _      => Err(()),
+            _ => Err(()),
         }
     }
 }
