@@ -67,10 +67,10 @@ impl NonVisualDrawingProperties {
         loop {
             match reader.read_event(&mut buf) {
                 Ok(Event::End(ref e)) => match e.name() {
-                    b"a:extLst" => return,
+                    b"xdr:cNvPr" => return,
                     _ => (),
                 },
-                Ok(Event::Eof) => panic!("Error not find {} end element", "a:extLst"),
+                Ok(Event::Eof) => panic!("Error not find {} end element", "xdr:cNvPr"),
                 Err(e) => panic!("Error at position {}: {:?}", reader.buffer_position(), e),
                 _ => (),
             }
@@ -82,7 +82,8 @@ impl NonVisualDrawingProperties {
         let with_inner = ole_id > &0;
         // xdr:cNvPr
         let mut attributes: Vec<(&str, &str)> = Vec::new();
-        attributes.push(("id", self.id.get_value_string()));
+        let id = self.id.get_value_string();
+        attributes.push(("id", &id));
         attributes.push(("name", self.name.get_value_string()));
         if self.hidden.has_value() {
             attributes.push(("hidden", self.hidden.get_value_string()));
