@@ -1,22 +1,18 @@
 // xdr:cNvGraphicFramePr
-use writer::driver::*;
-use quick_xml::events::{BytesStart};
-use quick_xml::Writer;
+use quick_xml::events::BytesStart;
 use quick_xml::Reader;
+use quick_xml::Writer;
 use std::io::Cursor;
+use writer::driver::*;
 
 #[derive(Clone, Default, Debug)]
-pub struct NonVisualGraphicFrameDrawingProperties {
-
-}
+pub struct NonVisualGraphicFrameDrawingProperties {}
 impl NonVisualGraphicFrameDrawingProperties {
-
     pub(crate) fn set_attributes<R: std::io::BufRead>(
         &mut self,
-        _reader:&mut Reader<R>,
-        _e:&BytesStart
+        _reader: &mut Reader<R>,
+        _e: &BytesStart,
     ) {
-
     }
 
     pub(crate) fn write_to(&self, writer: &mut Writer<Cursor<Vec<u8>>>) {
