@@ -34,7 +34,7 @@ impl Tint {
         write_start_tag(
             writer,
             "a:tint",
-            vec![("val", self.val.get_value_string())],
+            vec![("val", &self.val.get_value_string())],
             true,
         );
     }
