@@ -1,6 +1,7 @@
 use super::GradientFill;
 use super::PatternFill;
 use super::PatternValues;
+use md5::Digest;
 use quick_xml::events::{BytesStart, Event};
 use quick_xml::Reader;
 use quick_xml::Writer;
@@ -70,7 +71,7 @@ impl Fill {
     pub(crate) fn get_hash_code(&self) -> String {
         format!(
             "{:x}",
-            md5::compute(format!(
+            md5::Md5::digest(format!(
                 "{}{}",
                 match &self.pattern_fill {
                     Some(v) => {
