@@ -35,7 +35,7 @@ impl FontSize {
             write_start_tag(
                 writer,
                 "sz",
-                vec![("val", self.val.get_value_string())],
+                vec![("val", &self.val.get_value_string())],
                 true,
             );
         }
