@@ -1,33 +1,21 @@
-#[derive(Clone, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct Int64Value {
     value: Option<i64>,
-    value_string: String,
-    value_default: i64,
-}
-impl Default for Int64Value {
-    fn default() -> Self {
-        Self {
-            value: None,
-            value_string: "0".into(),
-            value_default: 0,
-        }
-    }
 }
 impl Int64Value {
     pub(crate) fn get_value(&self) -> &i64 {
         match &self.value {
             Some(v) => v,
-            None => &self.value_default,
+            None => &0,
         }
     }
 
-    pub(crate) fn get_value_string(&self) -> &str {
-        &self.value_string
+    pub(crate) fn get_value_string(&self) -> String {
+        self.get_value().to_string()
     }
 
     pub(crate) fn set_value(&mut self, value: i64) -> &mut Int64Value {
         self.value = Some(value);
-        self.value_string = value.to_string();
         self
     }
 
@@ -42,10 +30,10 @@ impl Int64Value {
         }
     }
 
-    pub(crate) fn _get_hash_string(&self) -> &str {
+    pub(crate) fn _get_hash_string(&self) -> String {
         if self.has_value() {
             return self.get_value_string();
         }
-        "empty!!"
+        String::from("empty!!")
     }
 }
