@@ -4,7 +4,7 @@ use quick_xml::Writer;
 use reader::driver::*;
 use std::io;
 use std::io::Read;
-use structs::raw::RawFile;
+
 use structs::raw::RawRelationship;
 use structs::StringValue;
 use structs::WriterManager;
@@ -40,36 +40,13 @@ impl RawRelationships {
         &mut self.relationship_list
     }
 
-    pub(crate) fn get_drawing_raw_file(&self) -> Option<&RawFile> {
+    pub(crate) fn get_relationship_by_rid(&self, r_id: &str) -> &RawRelationship {
         for relationship in self.get_relationship_list() {
-            if relationship.get_type()
-                == "http://schemas.openxmlformats.org/officeDocument/2006/relationships/drawing"
-            {
-                return Some(relationship.get_raw_file());
-            }
-        }
-        None
-    }
-
-    pub(crate) fn get_vml_drawing_raw_file(&self) -> Option<&RawFile> {
-        for relationship in self.get_relationship_list() {
-            if relationship.get_type()
-                == "http://schemas.openxmlformats.org/officeDocument/2006/relationships/vmlDrawing"
-            {
-                return Some(relationship.get_raw_file());
-            }
-        }
-        None
-    }
-
-    pub(crate) fn get_relationship_by_rid<S: Into<String>>(&self, r_id: S) -> &RawRelationship {
-        let r_id_str = r_id.into();
-        for relationship in self.get_relationship_list() {
-            if relationship.get_id() == r_id_str.as_str() {
+            if relationship.get_id() == r_id {
                 return relationship;
             }
         }
-        panic!("not found relationship as {}.", &r_id_str);
+        panic!("not found relationship as {}.", r_id);
     }
 
     pub(crate) fn add_relationship_list(&mut self, value: RawRelationship) -> &mut Self {
@@ -82,13 +59,13 @@ impl RawRelationships {
         arv: &mut zip::read::ZipArchive<R>,
         base_path: &str,
         target: &str,
-    ) {
+    ) -> bool {
         let data = {
             let path_str = normalize_path_to_str(&format!("{}/{}", base_path, target));
             let file_path = match arv.by_name(&path_str) {
                 Ok(v) => v,
                 Err(_) => {
-                    return;
+                    return false;
                 }
             };
             self.set_file_target(path_str);
@@ -117,6 +94,7 @@ impl RawRelationships {
             }
             buf.clear();
         }
+        true
     }
 
     pub(crate) fn write_to<W: io::Seek + io::Write>(
@@ -124,7 +102,7 @@ impl RawRelationships {
         writer_mng: &mut WriterManager<W>,
         ather_target: Option<&str>,
     ) -> Result<(), XlsxError> {
-        if self.get_relationship_list().len() == 0 {
+        if self.get_relationship_list().is_empty() {
             return Ok(());
         }
 
