@@ -1,33 +1,21 @@
-#[derive(Clone, Debug)]
+#[derive(Clone, Default, Debug)]
 pub struct UInt16Value {
     value: Option<u16>,
-    value_string: String,
-    value_default: u16,
-}
-impl Default for UInt16Value {
-    fn default() -> Self {
-        Self {
-            value: None,
-            value_string: String::from("0"),
-            value_default: 0,
-        }
-    }
 }
 impl UInt16Value {
     pub(crate) fn get_value(&self) -> &u16 {
         match &self.value {
             Some(v) => v,
-            None => &self.value_default,
+            None => &0,
         }
     }
 
-    pub(crate) fn get_value_string(&self) -> &str {
-        &self.value_string
+    pub(crate) fn get_value_string(&self) -> String {
+        self.get_value().to_string()
     }
 
     pub(crate) fn set_value(&mut self, value: u16) -> &mut UInt16Value {
         self.value = Some(value);
-        self.value_string = value.to_string();
         self
     }
 
@@ -41,11 +29,4 @@ impl UInt16Value {
             None => false,
         }
     }
-
-    pub(crate) fn _get_hash_string(&self) -> &str {
-        if self._has_value() {
-            return self.get_value_string();
-        }
-        "empty!!"
-    }
 }
