@@ -1,33 +1,21 @@
-#[derive(Clone, Debug, Eq, Ord, PartialEq, PartialOrd)]
+#[derive(Clone, Default, Debug, Eq, Ord, PartialEq, PartialOrd)]
 pub struct UInt32Value {
     value: Option<u32>,
-    value_string: String,
-    value_default: u32,
-}
-impl Default for UInt32Value {
-    fn default() -> Self {
-        Self {
-            value: None,
-            value_string: String::from("0"),
-            value_default: 0,
-        }
-    }
 }
 impl UInt32Value {
     pub(crate) fn get_value(&self) -> &u32 {
         match &self.value {
             Some(v) => v,
-            None => &self.value_default,
+            None => &0,
         }
     }
 
-    pub(crate) fn get_value_string(&self) -> &str {
-        &self.value_string
+    pub(crate) fn get_value_string(&self) -> String {
+        self.get_value().to_string()
     }
 
     pub(crate) fn set_value(&mut self, value: u32) -> &mut Self {
         self.value = Some(value);
-        self.value_string = value.to_string();
         self
     }
 
@@ -37,7 +25,6 @@ impl UInt32Value {
 
     pub(crate) fn remove_value(&mut self) -> &mut Self {
         self.value = None;
-        self.value_string = String::from("");
         self
     }
 
@@ -48,10 +35,10 @@ impl UInt32Value {
         }
     }
 
-    pub(crate) fn get_hash_string(&self) -> &str {
+    pub(crate) fn get_hash_string(&self) -> String {
         if self.has_value() {
             return self.get_value_string();
         }
-        "empty!!"
+        String::from("empty!!")
     }
 }
