@@ -1,6 +1,6 @@
 use super::EnumTrait;
 use std::str::FromStr;
-#[derive(Clone, Debug)]
+#[derive(Clone, Debug, Eq, Ord, PartialEq, PartialOrd)]
 pub enum UnderlineValues {
     Double,
     DoubleAccounting,
