@@ -213,8 +213,11 @@ pub fn write_writer<W: io::Seek + io::Write>(
 /// let path = std::path::Path::new("./tests/result_files/zzz.xlsx");
 /// let _ = umya_spreadsheet::writer::xlsx::write(&book, path);
 /// ```
-pub fn write(spreadsheet: &Spreadsheet, path: &Path) -> Result<(), XlsxError> {
-    let path_tmp = format!("{}.tmp", path.to_str().unwrap());
+pub fn write<P: AsRef<Path>>(spreadsheet: &Spreadsheet, path: P) -> Result<(), XlsxError> {
+    let extension = path.as_ref().extension().unwrap().to_str().unwrap();
+    let path_tmp = path
+        .as_ref()
+        .with_extension(format!("{}{}", extension, "tmp"));
     match write_writer(
         spreadsheet,
         &mut io::BufWriter::new(fs::File::create(&path_tmp)?),
@@ -225,6 +228,6 @@ pub fn write(spreadsheet: &Spreadsheet, path: &Path) -> Result<(), XlsxError> {
             return Err(v);
         }
     }
-    fs::rename(path_tmp, path.to_str().unwrap())?;
+    fs::rename(path_tmp, path)?;
     Ok(())
 }
