@@ -118,7 +118,7 @@ pub(crate) fn write<W: io::Seek + io::Write>(
         let id = index.to_string();
         let r_id = format!("rId{}", index);
         let mut attributes: Vec<(&str, &str)> = Vec::new();
-        attributes.push(("name", worksheet.get_title()));
+        attributes.push(("name", worksheet.get_name()));
         attributes.push(("sheetId", &id));
         attributes.push(("r:id", &r_id));
 
@@ -166,8 +166,25 @@ pub(crate) fn write<W: io::Seek + io::Write>(
         true,
     );
 
+    // pivotCaches
+    let pivot_cache_definition_collection = spreadsheet.get_pivot_caches();
+    if !pivot_cache_definition_collection.is_empty() {
+        write_start_tag(&mut writer, "pivotCaches", vec![], false);
+        for (_, val2, _) in pivot_cache_definition_collection {
+            let r_id = format!("rId{}", index);
+            write_start_tag(
+                &mut writer,
+                "pivotCache",
+                vec![("cacheId", &val2), ("r:id", &r_id)],
+                true,
+            );
+            index += 1;
+        }
+        write_end_tag(&mut writer, "pivotCaches");
+    }
+
     write_end_tag(&mut writer, "workbook");
 
-    make_file_from_writer("xl/workbook.xml", writer_mng.get_arv_mut(), writer, None)?;
-    Ok(())
+    let target = "xl/workbook.xml";
+    writer_mng.add_writer(target, writer)
 }
