@@ -42,7 +42,18 @@ pub(crate) fn write<W: io::Seek + io::Write>(
             &path_str,
             "",
         );
+        index += 1;
+    }
 
+    // relationships pivot_cache_definition
+    for (_, _, pivot_cache_definition) in spreadsheet.get_pivot_caches() {
+        write_relationship(
+            &mut writer,
+            &index.to_string(),
+            "http://schemas.openxmlformats.org/officeDocument/2006/relationships/pivotCacheDefinition",
+            pivot_cache_definition.as_str(),
+            "",
+        );
         index += 1;
     }
 
@@ -112,7 +123,7 @@ fn write_relationship(
     attributes.push(("Id", r_id.as_str()));
     attributes.push(("Type", p_type));
     attributes.push(("Target", p_target));
-    if p_target_mode != "" {
+    if !p_target_mode.is_empty() {
         attributes.push(("TargetMode", p_target_mode));
     }
     write_start_tag(writer, tag_name, attributes, true);
