@@ -1,5 +1,6 @@
 extern crate chrono;
 extern crate umya_spreadsheet;
+use std::time::Instant;
 
 #[test]
 fn read_and_wite() {
@@ -37,6 +38,17 @@ fn lazy_read_and_wite() {
     let _ = umya_spreadsheet::writer::xlsx::write(&book, path);
 }
 
+#[test]
+fn read_and_wite_libre2() {
+    // reader
+    let path = std::path::Path::new("./tests/test_files/libre2.xlsx");
+    let book = umya_spreadsheet::reader::xlsx::read(path).unwrap();
+
+    // writer
+    let path = std::path::Path::new("./tests/result_files/libre2.xlsx");
+    let _ = umya_spreadsheet::writer::xlsx::write(&book, path);
+}
+
 #[test]
 fn read_large_string() {
     // reader
@@ -48,20 +60,41 @@ fn read_large_string() {
 #[test]
 fn lazy_read_and_wite_large_string() {
     // reader
+    let start = Instant::now();
     let path = std::path::Path::new("./tests/test_files/aaa_large_string.xlsx");
     let mut book = umya_spreadsheet::reader::xlsx::lazy_read(path).unwrap();
     let ns = book.new_sheet("new sheet").unwrap();
+    let end = start.elapsed();
+    println!(
+        "read:{}.{:03}sec.",
+        end.as_secs(),
+        end.subsec_nanos() / 1_000_000
+    );
 
+    let start = Instant::now();
     for r in 1..5000 {
         for c in 1..30 {
             let cell = ns.get_cell_by_column_and_row_mut(&c, &r);
             let _ = cell.set_value_from_string(format!("r{}c{}", r, c));
         }
     }
+    let end = start.elapsed();
+    println!(
+        "edit:{}.{:03}sec.",
+        end.as_secs(),
+        end.subsec_nanos() / 1_000_000
+    );
 
     // writer
+    let start = Instant::now();
     let path = std::path::Path::new("./tests/result_files/bbb_large_string.xlsx");
     let _ = umya_spreadsheet::writer::xlsx::write(&book, path);
+    let end = start.elapsed();
+    println!(
+        "write:{}.{:03}sec.",
+        end.as_secs(),
+        end.subsec_nanos() / 1_000_000
+    );
 }
 
 #[test]
@@ -77,85 +110,94 @@ fn lazy_read_and_wite_no_edit() {
 
 fn read_and_wite_method(book: &mut umya_spreadsheet::Spreadsheet) {
     let _ = book
-        .get_sheet_mut(0)
+        .get_sheet_mut(&0)
         .unwrap()
         .get_cell_mut("A1")
         .set_value("TEST1");
-    let a1_value = book.get_sheet(0).unwrap().get_value("A1");
+    let a1_value = book.get_sheet(&0).unwrap().get_value("A1");
     assert_eq!("TEST1", a1_value);
     let _ = book
-        .get_sheet_mut(0)
+        .get_sheet_mut(&0)
         .unwrap()
         .remove_cell_by_column_and_row_mut(&1, &1);
-    let a1 = book.get_sheet(0).unwrap().get_cell("A1");
+    let a1 = book.get_sheet(&0).unwrap().get_cell("A1");
     assert_eq!(a1, None);
     let _ = book
-        .get_sheet_mut(0)
+        .get_sheet_mut(&0)
         .unwrap()
         .remove_cell_by_column_and_row_mut(&1, &2);
-    let a2_value = book.get_sheet(0).unwrap().get_value("A2");
+    let a2_value = book.get_sheet(&0).unwrap().get_value("A2");
     assert_eq!(a2_value, "");
-    let b5_value = book.get_sheet(0).unwrap().get_value("B5");
+    let b5_value = book.get_sheet(&0).unwrap().get_value("B5");
     assert_eq!(" ", b5_value);
 
     assert_eq!(
         "1.0000",
-        book.get_sheet(0)
+        book.get_sheet(&0)
             .unwrap()
             .get_formatted_value_by_column_and_row(&2, &20)
     );
     assert_eq!(
         "$3,333.0000",
-        book.get_sheet(0).unwrap().get_formatted_value("B21")
+        book.get_sheet(&0).unwrap().get_formatted_value("B21")
     );
     assert_eq!(
         "$ 333.00",
-        book.get_sheet(0).unwrap().get_formatted_value("B22")
+        book.get_sheet(&0).unwrap().get_formatted_value("B22")
     );
     assert_eq!(
         "2020年3月",
-        book.get_sheet(0).unwrap().get_formatted_value("B23")
+        book.get_sheet(&0).unwrap().get_formatted_value("B23")
     );
     assert_eq!(
         "2:33 pm",
-        book.get_sheet(0).unwrap().get_formatted_value("B24")
+        book.get_sheet(&0).unwrap().get_formatted_value("B24")
     );
     assert_eq!(
         "5.00%",
-        book.get_sheet(0).unwrap().get_formatted_value("B25")
+        book.get_sheet(&0).unwrap().get_formatted_value("B25")
+    );
+    assert_eq!(
+        "1/2",
+        book.get_sheet(&0).unwrap().get_formatted_value("B26")
     );
-    assert_eq!("1/2", book.get_sheet(0).unwrap().get_formatted_value("B26"));
     assert_eq!(
         "12/15/2020 14:01",
-        book.get_sheet(0).unwrap().get_formatted_value("B27")
+        book.get_sheet(&0).unwrap().get_formatted_value("B27")
+    );
+    assert_eq!(
+        "444",
+        book.get_sheet(&0).unwrap().get_formatted_value("B28")
     );
-    assert_eq!("444", book.get_sheet(0).unwrap().get_formatted_value("B28"));
     assert_eq!(
         "14-Dec-20",
-        book.get_sheet(0).unwrap().get_formatted_value("B29")
+        book.get_sheet(&0).unwrap().get_formatted_value("B29")
     );
     assert_eq!(
         "2020年10月1日",
-        book.get_sheet(0).unwrap().get_formatted_value("B30")
+        book.get_sheet(&0).unwrap().get_formatted_value("B30")
     );
     assert_eq!(
         "1.2345",
-        book.get_sheet(0).unwrap().get_formatted_value("B31")
+        book.get_sheet(&0).unwrap().get_formatted_value("B31")
+    );
+    assert_eq!(
+        "1.2",
+        book.get_sheet(&0).unwrap().get_formatted_value("B32")
     );
-    assert_eq!("1.2", book.get_sheet(0).unwrap().get_formatted_value("B32"));
     assert_eq!(
         "12,345,675,544.00",
-        book.get_sheet(0).unwrap().get_formatted_value("B33")
+        book.get_sheet(&0).unwrap().get_formatted_value("B33")
     );
     assert_eq!(
         "1.235",
-        book.get_sheet(0).unwrap().get_formatted_value("B34")
+        book.get_sheet(&0).unwrap().get_formatted_value("B34")
     );
-    assert_eq!("1", book.get_sheet(0).unwrap().get_formatted_value("B35"));
-    assert_eq!("", book.get_sheet(0).unwrap().get_formatted_value("B36"));
+    assert_eq!("1", book.get_sheet(&0).unwrap().get_formatted_value("B35"));
+    assert_eq!("", book.get_sheet(&0).unwrap().get_formatted_value("B36"));
     assert_eq!(
         "123456789012345678",
-        book.get_sheet(0).unwrap().get_formatted_value("B37")
+        book.get_sheet(&0).unwrap().get_formatted_value("B37")
     );
 
     let _ = book
@@ -259,12 +301,12 @@ fn lazy_read_and_wite_xlsm_no_edit() {
 
 fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
     let _ = book
-        .get_sheet_mut(0)
+        .get_sheet_mut(&0)
         .unwrap()
         .get_cell_by_column_and_row_mut(&1, &1)
         .set_value("TEST1");
     let a1_value = book
-        .get_sheet(0)
+        .get_sheet(&0)
         .unwrap()
         .get_cell_by_column_and_row(&1, &1)
         .unwrap()
@@ -272,12 +314,12 @@ fn read_and_wite_xlsm_method(book: &mut umya_spreadsheet::Spreadsheet) {
     assert_eq!("TEST1", a1_value);
 
     // copy sheet
-    let mut clone_sheet = book.get_sheet(0).unwrap().clone();
+    let mut clone_sheet = book.get_sheet(&0).unwrap().clone();
     clone_sheet.set_name("New Sheet");
     let _ = book.add_sheet(clone_sheet);
 
     // remove sheet
-    let mut clone_sheet = book.get_sheet(0).unwrap().clone();
+    let mut clone_sheet = book.get_sheet(&0).unwrap().clone();
     clone_sheet.set_name("DeletedSheet");
     let _ = book.add_sheet(clone_sheet);
     book.get_sheet_by_name("DeletedSheet").unwrap();
@@ -754,24 +796,17 @@ fn new_file_and_edit() {
     book.get_sheet_by_name_mut("Sheet2")
         .unwrap()
         .get_style_mut("A1")
-        .get_fill_mut()
-        .get_pattern_fill_mut()
-        .get_foreground_color_mut()
-        .set_argb(umya_spreadsheet::Color::COLOR_BLUE);
+        .set_background_color(umya_spreadsheet::Color::COLOR_BLUE);
 
-    // change background color part2.
-    let mut color = umya_spreadsheet::Color::default();
-    color.set_argb(umya_spreadsheet::Color::COLOR_BLUE);
-    let mut pattern_fill = umya_spreadsheet::PatternFill::default();
-    pattern_fill.set_foreground_color(color);
-    let mut fill = umya_spreadsheet::Fill::default();
-    fill.set_pattern_fill(pattern_fill);
-    let mut style = umya_spreadsheet::Style::default();
-    style.set_fill(fill);
     book.get_sheet_by_name_mut("Sheet2")
         .unwrap()
-        .set_style("A2", style);
-    
+        .get_style_mut("A2")
+        .set_background_color_with_pattern(
+            umya_spreadsheet::Color::COLOR_BLUE,
+            umya_spreadsheet::Color::COLOR_RED,
+            umya_spreadsheet::PatternValues::DarkGrid,
+        );
+
     let worksheet = book.get_sheet_by_name_mut("Sheet3").unwrap();
     worksheet.get_column_dimension_mut("A").set_auto_width(true);
 
@@ -911,3 +946,36 @@ fn new_file_empty_worksheet() {
     let path = std::path::Path::new("./tests/result_files/empty_worksheet.xlsx");
     let _ = umya_spreadsheet::writer::xlsx::write(&book, path);
 }
+
+#[test]
+fn google() {
+    // reader
+    let path = std::path::Path::new("./tests/test_files/google.xlsx");
+    let book = umya_spreadsheet::reader::xlsx::read(path).unwrap();
+
+    // writer
+    let path = std::path::Path::new("./tests/result_files/google.xlsx");
+    let _ = umya_spreadsheet::writer::xlsx::write(&book, path);
+}
+
+#[test]
+fn libre() {
+    // reader
+    let path = std::path::Path::new("./tests/test_files/libre.xlsm");
+    let book = umya_spreadsheet::reader::xlsx::read(path).unwrap();
+
+    // writer
+    let path = std::path::Path::new("./tests/result_files/libre.xlsm");
+    let _ = umya_spreadsheet::writer::xlsx::write(&book, path);
+}
+
+#[test]
+fn read_and_wite_theme() {
+    // reader
+    let path = std::path::Path::new("./tests/test_files/aaa_theme.xlsx");
+    let book = umya_spreadsheet::reader::xlsx::read(path).unwrap();
+
+    // writer
+    let path = std::path::Path::new("./tests/result_files/bbb_theme.xlsx");
+    let _ = umya_spreadsheet::writer::xlsx::write(&book, path);
+}
